@@ -26,12 +26,16 @@ DEBUG : print as much information as possible to isolate the cause of a bug.
 
 from dipy.align._public import (syn_registration, register_dwi_to_template, # noqa
                                 write_mapping, read_mapping, resample,
-                                center_of_mass, translation, rigid, affine,
+                                center_of_mass, translation,
+                                rigid_isoscaling, rigid_scaling,
+                                rigid, affine, motion_correction,
                                 affine_registration, register_series,
                                 register_dwi_series, streamline_registration)
 
 __all__ = ["syn_registration", "register_dwi_to_template",
            "write_mapping", "read_mapping", "resample",
-           "center_of_mass", "translation", "rigid", "affine",
+           "center_of_mass", "translation",
+           "rigid_isoscaling", "rigid_scaling",
+           "rigid", "affine", "motion_correction",
            "affine_registration", "register_series",
            "register_dwi_series", "streamline_registration"]
