@@ -43,6 +43,8 @@
 
 """
 
+from warnings import warn
+
 import numpy as np
 import numpy.linalg as npl
 import scipy.ndimage as ndimage
@@ -59,7 +61,7 @@ from dipy.align.scalespace import IsotropicScaleSpace
 from dipy.utils.deprecator import deprecated_params
 
 _interp_options = ['nearest', 'linear']
-_transform_method = {}
+_transform_method = dict()
 _transform_method[(2, 'nearest')] = vf.transform_2d_affine_nn
 _transform_method[(3, 'nearest')] = vf.transform_3d_affine_nn
 _transform_method[(2, 'linear')] = vf.transform_2d_affine
@@ -79,7 +81,7 @@ class AffineMap(object):
 
     def __init__(self, affine, domain_grid_shape=None, domain_grid2world=None,
                  codomain_grid_shape=None, codomain_grid2world=None):
-        """ AffineMap
+        """ AffineMap.
 
         Implements an affine transformation whose domain is given by
         `domain_grid` and `domain_grid2world`, and whose co-domain is
@@ -215,12 +217,11 @@ class AffineMap(object):
         return str(self.affine)
 
     def __repr__(self):
-        """Relodable representation - also relies on ndarray's implementation."""
-
+        """Reloadable representation - relies on ndarray's implementation."""
         return self.affine.__repr__()
 
     def __format__(self, format_spec):
-        """Implementation various formatting options"""
+        """ Implementation various formatting options."""
 
         if format_spec is None or self.affine is None:
             return str(self.affine)
@@ -506,7 +507,8 @@ class MutualInformationMetric(object):
         self.metric_grad = None
 
     def setup(self, transform, static, moving, static_grid2world=None,
-              moving_grid2world=None, starting_affine=None):
+              moving_grid2world=None, starting_affine=None,
+              static_mask=None, moving_mask=None):
         r"""Prepare the metric to compute intensity densities and gradients.
 
         The histograms will be setup to compute probability densities of
@@ -537,6 +539,12 @@ class MutualInformationMetric(object):
             instead of manually transforming the moving image to reduce
             interpolation artifacts. The default is None, implying no
             pre-alignment is performed.
+        static_mask : array, shape (S, R, C) or (R, C), optional
+            static image mask that defines which pixels in the static image
+            are used to calculate the mutual information.
+        moving_mask : array, shape (S', R', C') or (R', C'), optional
+            moving image mask that defines which pixels in the moving image
+            are used to calculate the mutual information.
 
         """
         n = transform.get_number_of_parameters()
@@ -566,6 +574,28 @@ class MutualInformationMetric(object):
         self.affine_map = AffineMap(P, static.shape, static_grid2world,
                                     moving.shape, moving_grid2world)
 
+        # Masks can only be used with dense sampling
+        if self.sampling_proportion in [None, 1.0]:
+
+            if static_mask is not None:
+                self.static_mask = static_mask.astype(np.int32)
+            else:
+                self.static_mask = None
+
+            if moving_mask is not None:
+                self.moving_mask = moving_mask.astype(np.int32)
+            else:
+                self.moving_mask = None
+
+        else:
+
+            if (static_mask is not None) or (moving_mask is not None):
+                wm = "Masking is not implemented for sampling_proportion < 1, "
+                wm = wm + "setting static_mask = None and moving_mask = None"
+                warn(wm, UserWarning)
+
+            self.static_mask, self.moving_mask = None, None
+
         if self.dim == 2:
             self.interp_method = interpolate_scalar_2d
         else:
@@ -592,7 +622,8 @@ class MutualInformationMetric(object):
             static_p = static_p[..., :self.dim]
             self.static_vals, inside = self.interp_method(static, static_p)
             self.static_vals = np.array(self.static_vals, dtype=np.float64)
-        self.histogram.setup(self.static, self.moving)
+        self.histogram.setup(self.static, self.moving,
+                             self.static_mask, self.moving_mask)
 
     def _update_histogram(self):
         r"""Update the histogram according to the current affine transform.
@@ -622,10 +653,21 @@ class MutualInformationMetric(object):
             results in an image of the same shape as the static image.
 
         """
+        static_mask_values, moving_mask_values = None, None
         if self.sampling_proportion is None:  # Dense case
             static_values = self.static
             moving_values = self.affine_map.transform(self.moving)
-            self.histogram.update_pdfs_dense(static_values, moving_values)
+
+            if self.static_mask is not None:
+                static_mask_values = self.static_mask
+            if self.moving_mask is not None:
+                moving_mask_values =\
+                 self.affine_map.transform(
+                    self.moving_mask, interpolation='nearest').astype(np.int32)
+
+            self.histogram.update_pdfs_dense(
+                static_values, moving_values,
+                self.static_mask, moving_mask_values)
         else:  # Sparse case
             sp_to_moving = self.moving_world2grid.dot(self.affine_map.affine)
             pts = sp_to_moving.dot(self.samples.T).T  # Points on moving grid
@@ -635,7 +677,8 @@ class MutualInformationMetric(object):
             static_values = self.static_vals
             moving_values = self.moving_vals
             self.histogram.update_pdfs_sparse(static_values, moving_values)
-        return static_values, moving_values
+        return static_values, moving_values,\
+            static_mask_values, moving_mask_values
 
     def _update_mutual_information(self, params, update_gradient=True):
         r"""Update marginal and joint distributions and the joint gradient.
@@ -669,7 +712,8 @@ class MutualInformationMetric(object):
         self.affine_map.set_affine(current_affine)
 
         # Update the histogram with the current joint intensities
-        static_values, moving_values = self._update_histogram()
+        static_values, moving_values, static_mask_values, moving_mask_values =\
+            self._update_histogram()
 
         H = self.histogram  # Shortcut to `self.histogram`
         grad = None  # Buffer to write the MI gradient into (if needed)
@@ -693,7 +737,9 @@ class MutualInformationMetric(object):
                     static_values,
                     moving_values,
                     static2prealigned,
-                    mgrad)
+                    mgrad,
+                    static_mask_values,
+                    moving_mask_values)
             else:  # Sparse case
                 # Compute the gradient of moving at the sampling points
                 # which are already given in physical space coordinates
@@ -888,7 +934,8 @@ class AffineRegistration(object):
 
     def _init_optimizer(self, static, moving, transform, params0,
                         static_grid2world, moving_grid2world,
-                        starting_affine):
+                        starting_affine,
+                        static_mask, moving_mask):
         r"""Initialize the registration optimizer.
 
         Initializes the optimizer by computing the scale space of the input
@@ -922,6 +969,12 @@ class AffineRegistration(object):
                 array, shape (dim+1, dim+1)
             If None:
                 Start from identity
+        static_mask : array, shape (S, R, C) or (R, C), optional
+            static image mask that defines which pixels in the static image
+            are used to calculate the mutual information.
+        moving_mask : array, shape (S', R', C') or (R', C'), optional
+            moving image mask that defines which pixels in the moving image
+            are used to calculate the mutual information.
 
         """
         self.dim = len(static.shape)
@@ -929,6 +982,25 @@ class AffineRegistration(object):
         n = transform.get_number_of_parameters()
         self.nparams = n
 
+        # ensure that masks are not all zeros
+        if np.all(static_mask == 0):
+            warn("static_mask is all zeros, setting to None (which means \
+                  the entire volume will be used)", UserWarning)
+            static_mask = None
+        if np.all(moving_mask == 0):
+            warn("moving_mask is all zeros, setting to None", UserWarning)
+            moving_mask = None
+
+        # save masks for use elsewhere
+        self.static_mask, self.moving_mask = static_mask, moving_mask
+
+        # multiply images by masks for transform_centers_of_mass
+        static_masked, moving_masked = static, moving
+        if static_mask is not None:
+            static_masked = static*static_mask
+        if moving_mask is not None:
+            moving_masked = moving*moving_mask
+
         if params0 is None:
             params0 = self.transform.get_identity_parameters()
         self.params0 = params0
@@ -936,11 +1008,12 @@ class AffineRegistration(object):
             self.starting_affine = np.eye(self.dim + 1)
         elif isinstance(starting_affine, str):
             if starting_affine == 'mass':
-                affine_map = transform_centers_of_mass(static,
+                affine_map = transform_centers_of_mass(static_masked,
                                                        static_grid2world,
-                                                       moving,
+                                                       moving_masked,
                                                        moving_grid2world)
                 self.starting_affine = affine_map.affine
+                print("starting_affine in imaffine:", self.starting_affine)
             elif starting_affine == 'voxel-origin':
                 affine_map = transform_origins(static, static_grid2world,
                                                moving, moving_grid2world)
@@ -958,16 +1031,26 @@ class AffineRegistration(object):
             self.starting_affine = starting_affine
         else:
             raise ValueError('Invalid starting_affine matrix')
+
         # Extract information from affine matrices to create the scale space
         static_direction, static_spacing = \
             get_direction_and_spacings(static_grid2world, self.dim)
         moving_direction, moving_spacing = \
             get_direction_and_spacings(moving_grid2world, self.dim)
 
-        static = ((static.astype(np.float64) - static.min()) /
-                  (static.max() - static.min()))
-        moving = ((moving.astype(np.float64) - moving.min()) /
-                  (moving.max() - moving.min()))
+        # Scale the images by min and max values (where mask == 1)
+        if static_mask is not None:
+            smin = np.min(static[static_mask == 1])
+            smax = np.max(static[static_mask == 1])
+        else:
+            smin, smax = np.min(static), np.max(static)
+        static = (static.astype(np.float64) - smin) / (smax - smin)
+        if moving_mask is not None:
+            mmin = np.min(moving[moving_mask == 1])
+            mmax = np.max(moving[moving_mask == 1])
+        else:
+            mmin, mmax = np.min(moving), np.max(moving)
+        moving = (moving.astype(np.float64) - mmin) / (mmax - mmin)
 
         # Build the scale space of the input images
         if self.use_isotropic:
@@ -980,6 +1063,7 @@ class AffineRegistration(object):
                                                  self.sigmas,
                                                  static_grid2world,
                                                  static_spacing, False)
+
         else:
             self.moving_ss = ScaleSpace(moving, self.levels, moving_grid2world,
                                         moving_spacing, self.ss_sigma_factor,
@@ -991,7 +1075,8 @@ class AffineRegistration(object):
 
     def optimize(self, static, moving, transform, params0,
                  static_grid2world=None, moving_grid2world=None,
-                 starting_affine=None, ret_metric=False):
+                 starting_affine=None, ret_metric=False,
+                 static_mask=None, moving_mask=None):
         r""" Start the optimization process.
 
         Parameters
@@ -1035,6 +1120,12 @@ class AffineRegistration(object):
             similarity between the images (default 'False').
             The metric containing optimal parameters and
             the distance between the images.
+        static_mask : array, shape (S, R, C) or (R, C), optional
+            static image mask that defines which pixels in the static image
+            are used to calculate the mutual information.
+        moving_mask : array, shape (S', R', C') or (R', C'), optional
+            moving image mask that defines which pixels in the moving image
+            are used to calculate the mutual information.
 
         Returns
         -------
@@ -1048,8 +1139,11 @@ class AffineRegistration(object):
         """
         self._init_optimizer(static, moving, transform, params0,
                              static_grid2world, moving_grid2world,
-                             starting_affine)
+                             starting_affine,
+                             static_mask, moving_mask)
         del starting_affine  # Now we must refer to self.starting_affine
+        del static_mask  # Now we must refer to self.static_mask
+        del moving_mask  # Now we must refer to self.moving_mask
 
         # Multi-resolution iterations
         original_static_shape = self.static_ss.get_image(0).shape
@@ -1078,15 +1172,21 @@ class AffineRegistration(object):
                                            original_static_shape,
                                            original_static_grid2world)
             current_static = current_affine_map.transform(smooth_static)
+            current_static_mask = None
+            if self.static_mask is not None:
+                current_static_mask = current_affine_map.transform(
+                    self.static_mask, interpolation="nearest").astype(np.int32)
 
             # The moving image is full resolution
             current_moving_grid2world = original_moving_grid2world
 
             current_moving = self.moving_ss.get_image(level)
+
             # Prepare the metric for iterations at this resolution
             self.metric.setup(transform, current_static, current_moving,
                               current_static_grid2world,
-                              current_moving_grid2world, self.starting_affine)
+                              current_moving_grid2world, self.starting_affine,
+                              current_static_mask, self.moving_mask)
 
             # Optimize this level
             if self.options is None:
@@ -1145,9 +1245,9 @@ def transform_centers_of_mass(static, static_grid2world,
         static_grid2world = np.eye(dim + 1)
     if moving_grid2world is None:
         moving_grid2world = np.eye(dim + 1)
-    c_static = ndimage.measurements.center_of_mass(np.array(static))
+    c_static = ndimage.center_of_mass(np.array(static))
     c_static = static_grid2world.dot(c_static + (1,))
-    c_moving = ndimage.measurements.center_of_mass(np.array(moving))
+    c_moving = ndimage.center_of_mass(np.array(moving))
     c_moving = moving_grid2world.dot(c_moving + (1,))
     transform = np.eye(dim + 1)
     transform[:dim, dim] = (c_moving - c_static)[:dim]
