@@ -4,6 +4,8 @@ from numpy.testing import (assert_equal,
                            assert_array_equal,
                            assert_array_almost_equal,
                            assert_raises)
+from dipy.core.interpolation import (interpolate_scalar_2d,
+                                     interpolate_scalar_3d)
 from dipy.data import get_fnames
 from dipy.align import floating
 from dipy.align import imwarp as imwarp
@@ -11,6 +13,7 @@ from dipy.align import metrics as metrics
 from dipy.align import vector_fields as vfu
 from dipy.align import VerbosityLevels
 from dipy.align.imwarp import DiffeomorphicMap
+from dipy.tracking.streamline import deform_streamlines
 
 
 def test_mult_aff():
@@ -95,8 +98,8 @@ def test_diffeomorphic_map_2d():
     # Verify that the transform method accepts different image types (note that
     # the actual image contained integer values, we don't want to test
     # rounding)
-    for type in [floating, np.float64, np.int64, np.int32]:
-        moving_image = moving_image.astype(type)
+    for _type in [floating, np.float64, np.int64, np.int32]:
+        moving_image = moving_image.astype(_type)
 
         # warp using linear interpolation
         warped = diff_map.transform(moving_image, 'linear')
@@ -123,8 +126,8 @@ def test_diffeomorphic_map_2d():
                                        codomain_shape, codomain_grid2world,
                                        domain_shape, domain_grid2world, None)
     diff_map.backward = disp
-    for type in [floating, np.float64, np.int64, np.int32]:
-        moving_image = moving_image.astype(type)
+    for _type in [floating, np.float64, np.int64, np.int32]:
+        moving_image = moving_image.astype(_type)
 
         # warp using linear interpolation
         warped = diff_map.transform_inverse(moving_image, 'linear')
@@ -486,8 +489,9 @@ def test_ssd_2d_gauss_newton():
     optimizer.ITER_END_CALLED = 0
 
     optimizer.verbosity = VerbosityLevels.DEBUG
-    id = np.eye(3)
-    mapping = optimizer.optimize(static, moving, id, id, id)
+    transformation = np.eye(3)
+    mapping = optimizer.optimize(
+        static, moving, transformation, transformation, transformation)
     m = optimizer.get_map()
     assert_equal(mapping, m)
 
@@ -546,7 +550,7 @@ def get_warped_stacked_image(image, nslices, b, m):
     mapping.forward, mapping.backward = d, dinv
     wimage = mapping.transform(image)
 
-    if(nslices == 1):
+    if nslices == 1:
         return image, wimage
 
     # normalize and form the 3d by piling slices
@@ -574,7 +578,7 @@ def get_synthetic_warped_circle(nslices):
     mapping.forward, mapping.backward = d, dinv
     wcircle = mapping.transform(circle)
 
-    if(nslices == 1):
+    if nslices == 1:
         return circle, wcircle
 
     # normalize and form the 3d by piling slices
@@ -959,3 +963,114 @@ def test_em_2d_demons():
     reduced = 1.0 - final_energy / starting_energy
 
     assert(reduced > 0.9)
+
+
+def test_coordinate_mapping():
+    r"""Test coordinate mapping with DiffeomorphicMap
+
+    1. Create a random displacement field and a small affine transform to map
+       grid to world coordinates.
+    2. Create a DiffeomorphicMap with the previously created field and affine
+       transform.
+    3. Create a random input image.
+    4. Select a few non-boundary voxels from the domain grid.
+    5. Warp the input image with the DiffeomorphicMap and interpolate the
+       **warped image** at the selected locations. The result is the
+       `expected` array.
+    6. Map only the selected points using the DiffeomorphicMap and
+       interpolate the **input image** at the warped points. The result is the
+       `actual` array, which should be almost equal to the `expected` array.
+    """
+    np.random.seed(1741332)
+    for dim in range(2, 4):
+        npoints = 100
+        points = np.empty((npoints, dim), dtype=np.float64)
+        if dim == 2:
+            domain_shape = (10, 10)
+            codomain_shape = (15, 15)
+            nr = domain_shape[0]
+            nc = domain_shape[1]
+            s = 1.1
+            t = 0.25
+            trans = np.array([[1, 0, -t*nr],
+                              [0, 1, -t*nc],
+                              [0, 0, 1]])
+            trans_inv = np.linalg.inv(trans)
+            scale = np.array([[1*s, 0, 0],
+                              [0, 1*s, 0],
+                              [0, 0, 1]])
+            gt_affine = trans_inv.dot(scale.dot(trans))
+            n = codomain_shape[0] * codomain_shape[1]
+            moving_image = np.random.randint(0, 10, n).reshape(codomain_shape)
+            moving_image = moving_image.astype(np.float64)
+            # Select a few grid coordinates not at the boundary of the domain
+            points[:, 0] = np.random.randint(1, nr-1, npoints)
+            points[:, 1] = np.random.randint(1, nc-1, npoints)
+            random_df = vfu.create_random_displacement_2d
+            interpolate_f = interpolate_scalar_2d
+        else:
+            domain_shape = (10, 10, 10)
+            codomain_shape = (15, 15, 15)
+            nr = domain_shape[0]
+            nc = domain_shape[1]
+            ns = domain_shape[2]
+            s = 1.1
+            t = 0.25
+            trans = np.array([[1, 0, 0, -t*ns],
+                              [0, 1, 0, -t*nr],
+                              [0, 0, 1, -t*nc],
+                              [0, 0, 0, 1]])
+            trans_inv = np.linalg.inv(trans)
+            scale = np.array([[1*s, 0, 0, 0],
+                              [0, 1*s, 0, 0],
+                              [0, 0, 1*s, 0],
+                              [0, 0, 0, 1]])
+            gt_affine = trans_inv.dot(scale.dot(trans))
+            n = codomain_shape[0] * codomain_shape[1] * codomain_shape[2]
+            moving_image = np.random.randint(0, 10, n).reshape(codomain_shape)
+            moving_image = moving_image.astype(np.float64)
+            # Select a few grid coordinates not at the boundary of the domain
+            points[:, 0] = np.random.randint(1, nr-1, npoints)
+            points[:, 1] = np.random.randint(1, nc-1, npoints)
+            points[:, 2] = np.random.randint(1, ns-1, npoints)
+            random_df = vfu.create_random_displacement_3d
+            interpolate_f = interpolate_scalar_3d
+
+        # create the random displacement field
+        domain_grid2world = gt_affine
+        codomain_grid2world = gt_affine
+        disp, assign = random_df(np.array(domain_shape, dtype=np.int32),
+                                 domain_grid2world,
+                                 np.array(codomain_shape, dtype=np.int32),
+                                 codomain_grid2world)
+        disp = disp.astype(floating)
+        # Create a DiffeomorphicMap instance
+        diff_map = imwarp.DiffeomorphicMap(dim, domain_shape,
+                                           domain_grid2world, domain_shape,
+                                           domain_grid2world, codomain_shape,
+                                           codomain_grid2world, None)
+        diff_map.forward = disp
+
+        # Here, expected is obtained after two interpolation steps, therefore
+        # we need to increase the tolerance when comparing against the result
+        # using only one interpolation step (we set decimal=5 below)
+        warped = diff_map.transform(moving_image, 'linear')
+        expected, inside = interpolate_f(warped, points)
+
+        # Now map the points with the implementation under test
+        # Specify how to map the given array to world coordinates
+        in2world = diff_map.domain_grid2world
+        # Request mapping back from world to grid coordinates
+        world2out = diff_map.domain_world2grid
+        # Execute warping
+        wpoints = diff_map.transform_points(points, in2world, world2out)
+        # Interpolate at warped points and verify it's equal to direct warping
+        actual, inside = interpolate_f(moving_image, wpoints)
+        assert_array_almost_equal(actual, expected, decimal=5)
+
+        if dim in [3, 4]:
+            wpoints_2 = deform_streamlines([points, ], disp, np.eye(4),
+                                           domain_grid2world, np.eye(4),
+                                           codomain_grid2world)
+
+            assert_array_almost_equal(wpoints, wpoints_2[0])
