@@ -2,8 +2,6 @@ import numpy as np
 import scipy as sp
 from numpy.testing import (assert_array_equal,
                            assert_array_almost_equal,
-                           assert_almost_equal,
-                           assert_equal,
                            assert_raises)
 from dipy.align import floating
 from dipy.align.imwarp import get_direction_and_spacings
@@ -43,7 +41,7 @@ def test_scale_space():
             for level in range(num_levels):
                 # Verify sigmas and images are consistent
                 sigmas = ss.get_sigmas(level)
-                expected = sp.ndimage.filters.gaussian_filter(original, sigmas)
+                expected = sp.ndimage.gaussian_filter(original, sigmas)
                 expected = ((expected - expected.min()) /
                             (expected.max() - expected.min()))
                 actual = ss.get_image(level)
