@@ -10,7 +10,9 @@ from dipy.align.streamlinear import (compose_matrix44,
                                      BundleMinDistanceMatrixMetric,
                                      BundleMinDistanceMetric,
                                      StreamlineLinearRegistration,
-                                     StreamlineDistanceMetric)
+                                     StreamlineDistanceMetric,
+                                     groupwise_slr,
+                                     get_unique_pairs)
 
 from dipy.tracking.streamline import (center_streamlines,
                                       unlist_streamlines,
@@ -21,7 +23,7 @@ from dipy.tracking.streamline import (center_streamlines,
 from dipy.io.streamline import load_tractogram
 from dipy.core.geometry import compose_matrix
 
-from dipy.data import get_fnames, two_cingulum_bundles
+from dipy.data import get_fnames, two_cingulum_bundles, read_five_af_bundles
 from dipy.align.bundlemin import (_bundle_minimum_distance_matrix,
                                   _bundle_minimum_distance,
                                   distance_matrix_mdf)
@@ -312,7 +314,7 @@ def test_matrix44():
 def test_abstract_metric_class():
 
     class DummyStreamlineMetric(StreamlineDistanceMetric):
-        def test():
+        def test(self):
             pass
     assert_raises(TypeError, DummyStreamlineMetric)
 
@@ -486,3 +488,42 @@ def test_wrong_num_threads():
 
     slr = StreamlineLinearRegistration(num_threads=0)
     assert_raises(ValueError, slr.optimize, A, B)
+
+
+def test_get_unique_pairs():
+
+    # Regular case
+    pairs, exclude = get_unique_pairs(6)
+    assert_equal(len(np.unique(pairs)), 6)
+    assert_equal(exclude, None)
+
+    # Odd case
+    pairs, exclude = get_unique_pairs(5)
+    assert_equal(len(np.unique(pairs)), 4)
+    assert_equal(isinstance(exclude, (int, np.int64, np.int32)), True)
+
+    # Iterative case
+    new_pairs, new_exclude = get_unique_pairs(5, pairs)
+    assert_equal(len(np.unique(pairs)), 4)
+    assert_equal(exclude != new_exclude, True)
+
+    # Check errors
+    assert_raises(TypeError, get_unique_pairs, 2.7)
+    assert_raises(ValueError, get_unique_pairs, 1)
+
+
+def test_groupwise_slr():
+
+    bundles = read_five_af_bundles()
+
+    # Test regular use case with convergence
+    new_bundles, T, d = groupwise_slr(bundles, verbose=True)
+
+    assert_equal(len(new_bundles), len(bundles))
+    assert_equal(type(new_bundles), list)
+    assert_equal(len(T), len(bundles))
+    assert_equal(type(T), list)
+
+    # Test regular use case without convergence (few iterations)
+    new_bundles, T, d = groupwise_slr(bundles, max_iter=3, tol=-10,
+                                      verbose=True)
