@@ -33,10 +33,10 @@ def iterate_residual_field_ssd_2d(delta_field, sigmasq_field, grad, target,
             y[:] = 0
             for (dRow, dCol) in [(-1, 0), (0, 1), (1, 0), (0, -1)]:
                 dr = r + dRow
-                if((dr < 0) or (dr >= nrows)):
+                if dr < 0 or dr >= nrows:
                     continue
                 dc = c + dCol
-                if((dc < 0) or (dc >= ncols)):
+                if dc < 0 or dc >= ncols:
                     continue
                 nn += 1
                 y += dfield[dr, dc]
@@ -47,9 +47,9 @@ def iterate_residual_field_ssd_2d(delta_field, sigmasq_field, grad, target,
                 tau = sigmasq * lambda_param * nn
                 A = np.outer(grad[r, c], grad[r, c]) + tau * np.eye(2)
                 det = np.linalg.det(A)
-                if(det < 1e-9):
+                if det < 1e-9:
                     nrm2 = np.sum(grad[r, c]**2)
-                    if(nrm2 < 1e-9):
+                    if nrm2 < 1e-9:
                         dfield[r, c, :] = 0
                     else:
                         dfield[r, c] = b[r, c] / nrm2
@@ -87,21 +87,21 @@ def iterate_residual_field_ssd_3d(delta_field, sigmasq_field, grad, target,
                 for dSlice, dRow, dCol in [(-1, 0, 0), (0, -1, 0), (0, 0, 1),
                                            (0, 1, 0), (0, 0, -1), (1, 0, 0)]:
                     ds = s + dSlice
-                    if((ds < 0) or (ds >= nslices)):
+                    if ds < 0 or ds >= nslices:
                         continue
                     dr = r + dRow
-                    if((dr < 0) or (dr >= nrows)):
+                    if dr < 0 or dr >= nrows:
                         continue
                     dc = c + dCol
-                    if((dc < 0) or (dc >= ncols)):
+                    if dc < 0 or dc >= ncols:
                         continue
                     nn += 1
                     y += dfield[ds, dr, dc]
-                if(np.isinf(sigmasq)):
+                if np.isinf(sigmasq):
                     dfield[s, r, c] = y / nn
-                elif(sigmasq < 1e-9):
+                elif sigmasq < 1e-9:
                     nrm2 = np.sum(g**2)
-                    if(nrm2 < 1e-9):
+                    if nrm2 < 1e-9:
                         dfield[s, r, c, :] = 0
                     else:
                         dfield[s, r, c, :] = b[s, r, c] / nrm2
@@ -113,7 +113,7 @@ def iterate_residual_field_ssd_3d(delta_field, sigmasq_field, grad, target,
                         dfield[s, r, c] = np.linalg.solve(G, y)
                     except np.linalg.linalg.LinAlgError:
                         nrm2 = np.sum(g**2)
-                        if(nrm2 < 1e-9):
+                        if nrm2 < 1e-9:
                             dfield[s, r, c, :] = 0
                         else:
                             dfield[s, r, c] = b[s, r, c] / nrm2
@@ -413,13 +413,16 @@ def test_solve_2d_symmetric_positive_definite():
     As = []
 
     # Identity
-    As.append(np.array([1.0, 0.0, 1.0]))
+    identity = np.array([1.0, 0.0, 1.0])
+    As.append(identity)
 
     # Small determinant
-    As.append(np.array([1e-3, 1e-4, 1e-3]))
+    small_det = np.array([1e-3, 1e-4, 1e-3])
+    As.append(small_det)
 
     # Large determinant
-    As.append(np.array([1e6, 1e4, 1e6]))
+    large_det = np.array([1e6, 1e4, 1e6])
+    As.append(large_det)
 
     for A in As:
         AA = np.array([[A[0], A[1]], [A[1], A[2]]])
@@ -444,7 +447,8 @@ def test_solve_3d_symmetric_positive_definite():
     gs = []
 
     # diagonal
-    gs.append(np.array([0.0, 0.0, 0.0]))
+    diag = np.array([0.0, 0.0, 0.0])
+    gs.append(diag)
 
     # canonical basis
     gs.append(np.array([1.0, 0.0, 0.0]))
