@@ -40,7 +40,7 @@ def unique_bvals(bvals, bmag=None, rbvals=False):
         Default: False
 
     Returns
-    ------
+    -------
     ubvals : ndarray
         Array containing the rounded unique b-values
     """
@@ -88,7 +88,7 @@ class GradientTable(object):
     gradient_table
 
     Notes
-    --------
+    -----
     The GradientTable object is immutable. Do NOT assign attributes.
     If you have your gradient table in a bval & bvec format, we recommend
     using the factory function gradient_table
@@ -297,9 +297,9 @@ def gradient_table_from_bvals_bvecs(bvals, bvecs, b0_threshold=50, atol=1e-2,
 
     # checking for the correctness of bvals
     if b0_threshold < bvals.min():
-        warn("b0_threshold (value: {0}) is too low, increase your \
-             b0_threshold. It should be higher than the lowest b0 value \
-             ({1}).".format(b0_threshold, bvals.min()))
+        warn("b0_threshold (value: {0}) is too low, increase your "
+             "b0_threshold. It should be higher than the lowest b0 value "
+             "({1}).".format(b0_threshold, bvals.min()))
 
     bvecs = np.where(np.isnan(bvecs), 0, bvecs)
     bvecs_close_to_1 = abs(vector_norm(bvecs) - 1) <= atol
@@ -644,12 +644,9 @@ def reorient_bvecs(gtab, affines, atol=1e-2):
         if aff.shape == (4, 4):
             # This must be an affine!
             # Remove the translation component:
-            aff_no_trans = aff[:3, :3]
-            # Decompose into rotation and scaling components:
-            R, S = polar(aff_no_trans)
-        elif aff.shape == (3, 3):
-            # We assume this is a rotation matrix:
-            R = aff
+            aff = aff[:3, :3]
+        # Decompose into rotation and scaling components:
+        R, S = polar(aff)
         Rinv = inv(R)
         # Apply the inverse of the rotation to the corresponding gradient
         # direction:
@@ -705,7 +702,7 @@ def round_bvals(bvals, bmag=None):
         larger b-value.
 
     Returns
-    ------
+    -------
     rbvals : ndarray
         Array containing the rounded b-values
     """
@@ -733,7 +730,7 @@ def unique_bvals_tolerance(bvals, tol=20):
         and the actual b-values.
 
     Returns
-    ------
+    -------
     ubvals : ndarray
         Array containing the unique b-values using the median value
         for each cluster
@@ -788,7 +785,7 @@ def get_bval_indices(bvals, bval, tol=20):
         and the actual b-values.
 
     Returns
-    ------
+    -------
     Array of indices where the b-value is `bval`
     """
     return np.where(np.logical_and(bvals <= bval + tol,
@@ -814,7 +811,7 @@ def unique_bvals_magnitude(bvals, bmag=None, rbvals=False):
         Default: False
 
     Returns
-    ------
+    -------
     ubvals : ndarray
         Array containing the rounded unique b-values
     """
@@ -935,7 +932,7 @@ def _btens_to_params_2d(btens_2d, ztol):
 
 
 def btens_to_params(btens, ztol=1e-10):
-    r"""Compute trace, anisotropy and assymetry parameters from b-tensors
+    r"""Compute trace, anisotropy and assymetry parameters from b-tensors.
 
     Parameters
     ----------
@@ -1006,7 +1003,7 @@ def btens_to_params(btens, ztol=1e-10):
 
 
 def params_to_btens(bval, bdelta, b_eta):
-    """Compute b-tensor from trace, anisotropy and assymetry parameters
+    """Compute b-tensor from trace, anisotropy and assymetry parameters.
 
     Parameters
     ----------
@@ -1050,10 +1047,10 @@ def params_to_btens(bval, bdelta, b_eta):
     if bval < 0:
         raise ValueError("`bval` must be >= 0")
 
-    if not (bdelta >= -0.5 and bdelta <= 1):
+    if not -0.5 <= bdelta <= 1:
         raise ValueError("`delta` must be >= -0.5 and <= 1")
 
-    if not (b_eta >= 0 and b_eta <= 1):
+    if not 0 <= b_eta <= 1:
         raise ValueError("`b_eta` must be >= 0 and <= 1")
 
     m1 = np.array([[-1, 0, 0], [0, -1, 0], [0, 0, 2]])
@@ -1061,3 +1058,106 @@ def params_to_btens(bval, bdelta, b_eta):
     btens = bval/3*(np.eye(3)+bdelta*(m1+b_eta*m2))
 
     return btens
+
+
+def ornt_mapping(ornt1, ornt2):
+    """Calculate the mapping needing to get from orn1 to orn2."""
+
+    mapping = np.empty((len(ornt1), 2), 'int')
+    mapping[:, 0] = -1
+    A = ornt1[:, 0].argsort()
+    B = ornt2[:, 0].argsort()
+    mapping[B, 0] = A
+    assert (mapping[:, 0] != -1).all()
+    sign = ornt2[:, 1] * ornt1[mapping[:, 0], 1]
+    mapping[:, 1] = sign
+    return mapping
+
+
+def reorient_vectors(bvecs, current_ornt, new_ornt, axis=0):
+    """Change the orientation of gradients or other vectors.
+
+    Moves vectors, storted along axis, from current_ornt to new_ornt. For
+    example the vector [x, y, z] in "RAS" will be [-x, -y, z] in "LPS".
+
+    R: Right
+    A: Anterior
+    S: Superior
+    L: Left
+    P: Posterior
+    I: Inferior
+
+    """
+    if isinstance(current_ornt, str):
+        current_ornt = orientation_from_string(current_ornt)
+    if isinstance(new_ornt, str):
+        new_ornt = orientation_from_string(new_ornt)
+
+    n = bvecs.shape[axis]
+    if current_ornt.shape != (n, 2) or new_ornt.shape != (n, 2):
+        raise ValueError("orientations do not match")
+
+    bvecs = np.asarray(bvecs)
+    mapping = ornt_mapping(current_ornt, new_ornt)
+    output = bvecs.take(mapping[:, 0], axis)
+    out_view = np.rollaxis(output, axis, output.ndim)
+    out_view *= mapping[:, 1]
+    return output
+
+
+def reorient_on_axis(bvecs, current_ornt, new_ornt, axis=0):
+    if isinstance(current_ornt, str):
+        current_ornt = orientation_from_string(current_ornt)
+    if isinstance(new_ornt, str):
+        new_ornt = orientation_from_string(new_ornt)
+
+    n = bvecs.shape[axis]
+    if current_ornt.shape != (n, 2) or new_ornt.shape != (n, 2):
+        raise ValueError("orientations do not match")
+
+    mapping = ornt_mapping(current_ornt, new_ornt)
+    order = [slice(None)] * bvecs.ndim
+    order[axis] = mapping[:, 0]
+    shape = [1] * bvecs.ndim
+    shape[axis] = -1
+    sign = mapping[:, 1]
+    sign.shape = shape
+    output = bvecs[order]
+    output *= sign
+    return output
+
+
+def orientation_from_string(string_ornt):
+    """Return an array representation of an ornt string."""
+    orientation_dict = dict(r=(0, 1), l=(0, -1), a=(1, 1),
+                            p=(1, -1), s=(2, 1), i=(2, -1))
+    ornt = tuple(orientation_dict[ii] for ii in string_ornt.lower())
+    ornt = np.array(ornt)
+    if _check_ornt(ornt):
+        msg = string_ornt + " does not seem to be a valid orientation string"
+        raise ValueError(msg)
+    return ornt
+
+
+def orientation_to_string(ornt):
+    """Return a string representation of a 3d ornt."""
+    if _check_ornt(ornt):
+        msg = repr(ornt) + " does not seem to be a valid orientation"
+        raise ValueError(msg)
+    orientation_dict = {(0, 1): 'r', (0, -1): 'l', (1, 1): 'a',
+                        (1, -1): 'p', (2, 1): 's', (2, -1): 'i'}
+    ornt_string = ''
+    for ii in ornt:
+        ornt_string += orientation_dict[(ii[0], ii[1])]
+    return ornt_string
+
+
+def _check_ornt(ornt):
+    uniq = np.unique(ornt[:, 0])
+    if len(uniq) != len(ornt):
+        print(len(uniq))
+        return True
+    uniq = np.unique(ornt[:, 1])
+    if tuple(uniq) not in {(-1, 1), (-1,), (1,)}:
+        print(tuple(uniq))
+        return True
