@@ -12,7 +12,7 @@ pstats, _, _ = optional_package('pstats',
                                 'python-profiler package in Debian/Ubuntu')
 
 
-class Profiler():
+class Profiler:
     """ Profile python/cython files or functions
 
     If you are profiling cython code you need to add
@@ -24,16 +24,16 @@ class Profiler():
     @cython.profile(False)
 
     Parameters
-    -------------
+    ----------
     caller : file or function call
     args : function arguments
 
     Attributes
-    ------------
+    ----------
     stats : function, stats.print_stats(10) will prin the 10 slower functions
 
     Examples
-    -----------
+    --------
     from dipy.core.profile import Profiler
     import numpy as np
     p=Profiler(np.sum,np.random.rand(1000000,3))
@@ -43,7 +43,7 @@ class Profiler():
     p.print_stats('det')
 
     References
-    -------------
+    ----------
     http://docs.cython.org/src/tutorial/profiling_tutorial.html
     http://docs.python.org/library/profile.html
     http://packages.python.org/line_profiler/
@@ -94,7 +94,7 @@ class Profiler():
         will give you the stats for all the calls with name 'function_name'
 
         Parameters
-        ------------
+        ----------
         N : stats.print_stats argument
 
         """
