@@ -160,7 +160,7 @@ def test_interpolate_scalar_nn_3d():
     for i in range(nsamples):
         expected_inside = 1
         for axis in range(3):
-            if (locations[i, axis] < 0 or locations[i, axis] > (sz - 1)):
+            if locations[i, axis] < 0 or locations[i, axis] > (sz - 1):
                 expected_inside = 0
                 break
         npt.assert_equal(inside[i], expected_inside)
