@@ -1,16 +1,13 @@
 """Read test or example data."""
 
-import os
-import sys
 import json
-import warnings
 import pickle
 
-from nibabel import load
-from os.path import join as pjoin, dirname
+from os.path import join as pjoin, dirname, exists
 
 import gzip
 import numpy as np
+from scipy.sparse import load_npz
 from dipy.core.gradients import GradientTable, gradient_table
 from dipy.core.sphere import Sphere, HemiSphere
 from dipy.data.fetcher import (get_fnames,
@@ -51,15 +48,21 @@ from dipy.data.fetcher import (get_fnames,
                                get_target_tractogram_hcp,
                                get_two_hcp842_bundles,
                                fetch_bundle_fa_hcp,
-                               fetch_gold_standard_io)
+                               fetch_gold_standard_io,
+                               fetch_resdnn_weights,
+                               read_qte_lte_pte,
+                               read_DiB_70_lte_pte_ste,
+                               read_DiB_217_lte_pte_ste,
+                               read_five_af_bundles,
+                               fetch_hbn)
 
 from ..utils.arrfuncs import as_native_array
 from dipy.io.image import load_nifti
 from dipy.tracking.streamline import relist_streamlines
 
 
-def loads_compat(bytes):
-    return pickle.loads(bytes, encoding='latin1')
+def loads_compat(byte_data):
+    return pickle.loads(byte_data, encoding='latin1')
 
 
 DATA_DIR = pjoin(dirname(__file__), 'files')
@@ -81,17 +84,17 @@ def get_sim_voxels(name='fib1'):
     """ provide some simulated voxel data
 
     Parameters
-    ------------
+    ----------
     name : str, which file?
         'fib0', 'fib1' or 'fib2'
 
     Returns
-    ---------
+    -------
     dix : dictionary, where dix['data'] returns a 2d array
         where every row is a simulated voxel with different orientation
 
     Examples
-    ----------
+    --------
     >>> from dipy.data import get_sim_voxels
     >>> sv=get_sim_voxels('fib1')
     >>> sv['data'].shape == (100, 102)
@@ -111,8 +114,9 @@ def get_sim_voxels(name='fib1'):
     '80'
 
     Notes
-    -------
+    -----
     These sim voxels were provided by M.M. Correia using Rician noise.
+
     """
     if name == 'fib0':
         fname = pjoin(DATA_DIR, 'fib0.pkl.gz')
@@ -124,10 +128,10 @@ def get_sim_voxels(name='fib1'):
 
 
 def get_skeleton(name='C1'):
-    """ provide skeletons generated from Local Skeleton Clustering (LSC)
+    """ Provide skeletons generated from Local Skeleton Clustering (LSC).
 
     Parameters
-    -----------
+    ----------
     name : str, 'C1' or 'C3'
 
     Returns
@@ -135,7 +139,7 @@ def get_skeleton(name='C1'):
     dix : dictionary
 
     Examples
-    ---------
+    --------
     >>> from dipy.data import get_skeleton
     >>> C=get_skeleton('C1')
     >>> len(C.keys())
@@ -143,6 +147,7 @@ def get_skeleton(name='C1'):
     >>> for c in C: break
     >>> sorted(C[c].keys())
     ['N', 'hidden', 'indices', 'most']
+
     """
     if name == 'C1':
         fname = pjoin(DATA_DIR, 'C1.pkl.gz')
@@ -155,7 +160,7 @@ def get_sphere(name='symmetric362'):
     """ provide triangulated spheres
 
     Parameters
-    ------------
+    ----------
     name : str
         which sphere - one of:
         * 'symmetric362'
@@ -183,6 +188,7 @@ def get_sphere(name='symmetric362'):
     Traceback (most recent call last):
         ...
     DataError: No sphere called "not a sphere name"
+
     """
     fname = SPHERE_FILES.get(name)
     if fname is None:
@@ -248,7 +254,7 @@ def mrtrix_spherical_functions():
     -------
     func_coef : array (2, 3, 4, 45)
         Functions represented by the coefficients associated with the
-        mxtrix spherical harmonic basis of order 8.
+        mrtrix spherical harmonic basis of order 8.
     func_discrete : array (2, 3, 4, 81)
         Functions evaluated on `sphere`.
     sphere : Sphere
@@ -292,7 +298,7 @@ def get_cmap(name):
             x, y0, y1 = zip(*desc[color])
             # Matplotlib allows more complex colormaps, but for users who do
             # not have Matplotlib dipy makes a few simple colormaps available.
-            # These colormaps are simple because y0 == y1, and therefor we
+            # These colormaps are simple because y0 == y1, and therefore we
             # ignore y1 here.
             rgba[:, i] = np.interp(v, x, y0)
         return rgba
@@ -312,3 +318,51 @@ def matlab_life_results():
     matlab_rmse = np.load(pjoin(DATA_DIR, 'life_matlab_rmse.npy'))
     matlab_weights = np.load(pjoin(DATA_DIR, 'life_matlab_weights.npy'))
     return matlab_rmse, matlab_weights
+
+
+def load_sdp_constraints(model_name, order=None):
+    """Import semidefinite programming constraint matrices for different models,
+    generated as described for example in [1]_.
+
+    Parameters
+    ----------
+    model_name : string
+        A string identifying the model that is to be constrained.
+    order : unsigned int, optional
+        A non-negative integer that represent the order or instance of the
+        model.
+        Default: None.
+
+    Returns
+    -------
+    sdp_constraints : array
+        Constraint matrices
+
+    Notes
+    -----
+    The constraints will be loaded from a file named 'id_constraint_order.npz'.
+
+    References
+    ----------
+    .. [1] Dela Haije et al. "Enforcing necessary non-negativity constraints
+           for common diffusion MRI models using sum of squares programming".
+           NeuroImage 209, 2020, 116405.
+
+    """
+
+    file = model_name + '_constraint'
+    if order is not None:
+        file += '_' + str(order)
+    file += '.npz'
+    path = pjoin(DATA_DIR, file)
+
+    if not exists(path):
+        raise ValueError("Constraints file '" + file + "' not found.")
+
+    try:
+        array = load_npz(path)
+        n, x = array.shape
+        sdp_constraints = [array[i*x:(i+1)*x] for i in range(n//x)]
+        return sdp_constraints
+    except Exception:
+        raise ValueError("Failed to read constraints file '" + file + "'.")
