@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 import os
-import sys
 import contextlib
 import logging
+import json
 
+import os.path as op
 from os.path import join as pjoin
 from hashlib import md5
 from shutil import copyfileobj
@@ -12,11 +13,15 @@ import numpy as np
 import nibabel as nib
 
 import tarfile
+import tempfile
 import zipfile
 from dipy.core.gradients import (gradient_table,
                                  gradient_table_from_gradient_strength_bvecs)
 from dipy.io.gradients import read_bvals_bvecs
-from dipy.io.image import load_nifti, load_nifti_data
+from dipy.io.image import load_nifti, load_nifti_data, save_nifti
+from dipy.io.streamline import load_trk
+from dipy.utils.optpkg import optional_package, TripWire
+
 
 from urllib.request import urlopen
 
@@ -24,13 +29,16 @@ from urllib.request import urlopen
 if 'DIPY_HOME' in os.environ:
     dipy_home = os.environ['DIPY_HOME']
 else:
-    dipy_home = pjoin(os.path.expanduser('~'), '.dipy')
+    dipy_home = pjoin(op.expanduser('~'), '.dipy')
 
 # The URL to the University of Washington Researchworks repository:
 UW_RW_URL = \
     "https://digital.lib.washington.edu/researchworks/bitstream/handle/"
 
 
+boto3, has_boto3, _ = optional_package('boto3')
+
+
 class FetcherError(Exception):
     pass
 
@@ -74,7 +82,7 @@ def check_md5(filename, stored_md5=None):
     string md5
 
     Parameters
-    -----------
+    ----------
     filename : string
         Path to a file.
     md5 : string
@@ -101,7 +109,7 @@ def _get_file_data(fname, url):
             response_size = None
 
         with open(fname, 'wb') as data:
-            if(response_size is None):
+            if response_size is None:
                 copyfileobj(opener, data)
             else:
                 copyfileobj_withprogress(opener, data, response_size)
@@ -129,8 +137,8 @@ def fetch_data(files, folder, data_size=None):
         value. The downloaded file is not deleted when this error is raised.
 
     """
-    if not os.path.exists(folder):
-        _log("Creating new folder %s" % (folder))
+    if not op.exists(folder):
+        _log("Creating new folder %s" % folder)
         os.makedirs(folder)
 
     if data_size is not None:
@@ -140,7 +148,7 @@ def fetch_data(files, folder, data_size=None):
     for f in files:
         url, md5 = files[f]
         fullpath = pjoin(folder, f)
-        if os.path.exists(fullpath) and (_get_file_md5(fullpath) == md5):
+        if op.exists(fullpath) and (_get_file_md5(fullpath) == md5):
             continue
         all_skip = False
         _log('Downloading "%s" to %s' % (f, folder))
@@ -149,7 +157,7 @@ def fetch_data(files, folder, data_size=None):
     if all_skip:
         _already_there_msg(folder)
     else:
-        _log("Files successfully downloaded to %s" % (folder))
+        _log("Files successfully downloaded to %s" % folder)
 
 
 def _make_fetcher(name, folder, baseurl, remote_fnames, local_fnames,
@@ -201,9 +209,9 @@ def _make_fetcher(name, folder, baseurl, remote_fnames, local_fnames,
             _log(msg)
         if unzip:
             for f in local_fnames:
-                split_ext = os.path.splitext(f)
+                split_ext = op.splitext(f)
                 if split_ext[-1] == '.gz' or split_ext[-1] == '.bz2':
-                    if os.path.splitext(split_ext[0])[-1] == '.tar':
+                    if op.splitext(split_ext[0])[-1] == '.tar':
                         ar = tarfile.open(pjoin(folder, f))
                         ar.extractall(path=folder)
                         ar.close()
@@ -271,6 +279,15 @@ fetch_stanford_hardi = _make_fetcher(
      '4c63a586f29afc6a48a5809524a76cb4'],
     doc="Download a HARDI dataset with 160 gradient directions")
 
+fetch_resdnn_weights = _make_fetcher(
+    "fetch_resdnn_weights",
+    pjoin(dipy_home, 'histo_resdnn_weights'),
+    'https://ndownloader.figshare.com/files/',
+    ['22736240'],
+    ['resdnn_weights_mri_2018.h5'],
+    ['f0e118d72ab804a464494bd9015227f4'],
+    doc="Download ResDNN model weights for Nath et. al 2018")
+
 fetch_stanford_t1 = _make_fetcher(
     "fetch_stanford_t1",
     pjoin(dipy_home, 'stanford_hardi'),
@@ -495,6 +512,18 @@ fetch_gold_standard_io = _make_fetcher(
     data_size="47.KB")
 
 
+fetch_qte_lte_pte = _make_fetcher(
+    'fetch_qte_lte_pte',
+    pjoin(dipy_home, 'qte_lte_pte'),
+    'https://zenodo.org/record/4624866/files/',
+    ['lte-pte.nii.gz', 'lte-pte.bval', 'lte-pte.bvec', 'mask.nii.gz'],
+    ['lte-pte.nii.gz', 'lte-pte.bval', 'lte-pte.bvec', 'mask.nii.gz'],
+    ['f378b2cd9f57625512002b9e4c0f1660', '5c25d24dd3df8590582ed690507a8769',
+     '31abe55dfda7ef5fdf5015d0713be9b0', '1b7b83b8a60295f52d80c3855a12b275'],
+    doc='Download QTE data with linear and planar tensor encoding.',
+    data_size='41.5 MB')
+
+
 fetch_fury_surface = _make_fetcher(
     "fetch_fury_surface",
     pjoin(dipy_home, 'fury_surface'),
@@ -505,6 +534,61 @@ fetch_fury_surface = _make_fetcher(
     doc="Surface for testing and examples",
     data_size="11MB")
 
+fetch_DiB_70_lte_pte_ste = _make_fetcher(
+    'fetch_DiB_70_lte_pte_ste',
+    pjoin(dipy_home, 'DiB_70_lte_pte_ste'),
+    'https://github.com/filip-szczepankiewicz/Szczepankiewicz_DIB_2019/'
+    'raw/master/DATA/brain/NII_Boito_SubSamples/',
+    ['DiB_70_lte_pte_ste/DiB_70_lte_pte_ste.nii.gz',
+     'DiB_70_lte_pte_ste/bval_DiB_70_lte_pte_ste.bval',
+     'DiB_70_lte_pte_ste/bvec_DiB_70_lte_pte_ste.bvec',
+     'DiB_mask.nii.gz'],
+    ['DiB_70_lte_pte_ste.nii.gz',
+     'bval_DiB_70_lte_pte_ste.bval',
+     'bvec_DiB_70_lte_pte_ste.bvec',
+     'DiB_mask.nii.gz'],
+    doc='Download QTE data with linear, planar, ' +
+        'and spherical tensor encoding. If using this data please cite ' +
+        'F Szczepankiewicz, S Hoge, C-F Westin. Linear, planar and ' +
+        'spherical tensor-valued diffusion MRI data by free waveform ' +
+        'encoding in healthy brain, water, oil and liquid crystals. ' +
+        'Data in Brief (2019),' +
+        'DOI: https://doi.org/10.1016/j.dib.2019.104208',
+    md5_list=['11f2e0d53e19061654eb3cdfc8fe9827',
+              '15021885b4967437c8cf441c09045c25',
+              '1e6b867182da249f81aa9abd50e8b9f7',
+              '2ea48d80b6ae1c3da50cb44e615b09e5'],
+    data_size='51.1 MB')
+
+fetch_DiB_217_lte_pte_ste = _make_fetcher(
+    'fetch_DiB_217_lte_pte_ste',
+    pjoin(dipy_home, 'DiB_217_lte_pte_ste'),
+    'https://github.com/filip-szczepankiewicz/Szczepankiewicz_DIB_2019/'
+    'raw/master/DATA/brain/NII_Boito_SubSamples/',
+    ['DiB_217_lte_pte_ste/DiB_217_lte_pte_ste_1.nii.gz',
+     'DiB_217_lte_pte_ste/DiB_217_lte_pte_ste_2.nii.gz',
+     'DiB_217_lte_pte_ste/bval_DiB_217_lte_pte_ste.bval',
+     'DiB_217_lte_pte_ste/bvec_DiB_217_lte_pte_ste.bvec',
+     'DiB_mask.nii.gz'],
+    ['DiB_217_lte_pte_ste_1.nii.gz',
+     'DiB_217_lte_pte_ste_2.nii.gz',
+     'bval_DiB_217_lte_pte_ste.bval',
+     'bvec_DiB_217_lte_pte_ste.bvec',
+     'DiB_mask.nii.gz'],
+    doc='Download QTE data with linear, planar, ' +
+        'and spherical tensor encoding. If using this data please cite ' +
+        'F Szczepankiewicz, S Hoge, C-F Westin. Linear, planar and ' +
+        'spherical tensor-valued diffusion MRI data by free waveform ' +
+        'encoding in healthy brain, water, oil and liquid crystals. ' +
+        'Data in Brief (2019),' +
+        'DOI: https://doi.org/10.1016/j.dib.2019.104208',
+    md5_list=['424e9cf75b20bc1f7ae1acde26b26da0',
+              '8e70d14fb8f08065a7a0c4d3033179c6',
+              '1f657215a475676ce333299038df3a39',
+              '4220ca92f2906c97ed4c7287eb62c6f0',
+              '2ea48d80b6ae1c3da50cb44e615b09e5'],
+    data_size='166.3 MB')
+
 
 def get_fnames(name='small_64D'):
     """Provide full paths to example or test datasets.
@@ -513,6 +597,7 @@ def get_fnames(name='small_64D'):
     ----------
     name : str
         the filename/s of which dataset to return, one of:
+
         - 'small_64D' small region of interest nifti,bvecs,bvals 64 directions
         - 'small_101D' small region of interest nifti, bvecs, bvals
           101 directions
@@ -549,14 +634,16 @@ def get_fnames(name='small_64D'):
     True
 
     """
-    DATA_DIR = pjoin(os.path.dirname(__file__), 'files')
+    DATA_DIR = pjoin(op.dirname(__file__), 'files')
     if name == 'small_64D':
         fbvals = pjoin(DATA_DIR, 'small_64D.bval')
         fbvecs = pjoin(DATA_DIR, 'small_64D.bvec')
         fimg = pjoin(DATA_DIR, 'small_64D.nii')
         return fimg, fbvals, fbvecs
-    if name == '55dir_grad.bvec':
-        return pjoin(DATA_DIR, '55dir_grad.bvec')
+    if name == '55dir_grad':
+        fbvals = pjoin(DATA_DIR, '55dir_grad.bval')
+        fbvecs = pjoin(DATA_DIR, '55dir_grad.bvec')
+        return fbvals, fbvecs
     if name == 'small_101D':
         fbvals = pjoin(DATA_DIR, 'small_101D.bval')
         fbvecs = pjoin(DATA_DIR, 'small_101D.bvec')
@@ -596,6 +683,8 @@ def get_fnames(name='small_64D'):
         return pjoin(DATA_DIR, 'circle.npy')
     if name == 'cb_2':
         return pjoin(DATA_DIR, 'cb_2.npz')
+    if name == 'minimal_bundles':
+        return pjoin(DATA_DIR, 'minimal_bundles.zip')
     if name == "t1_coronal_slice":
         return pjoin(DATA_DIR, 't1_coronal_slice.npy')
     if name == "t-design":
@@ -605,7 +694,7 @@ def get_fnames(name='small_64D'):
         files, folder = fetch_scil_b0()
         files = files['datasets_multi-site_all_companies.zip'][2]
         files = [pjoin(folder, f) for f in files]
-        return [f for f in files if os.path.isfile(f)]
+        return [f for f in files if op.isfile(f)]
     if name == 'stanford_hardi':
         files, folder = fetch_stanford_hardi()
         fraw = pjoin(folder, 'HARDI150.nii.gz')
@@ -675,10 +764,36 @@ def get_fnames(name='small_64D'):
     if name == 'bundle_atlas_hcp842':
         files, folder = fetch_bundle_atlas_hcp842()
         return get_bundle_atlas_hcp842()
+    if name == 'qte_lte_pte':
+        _, folder = fetch_qte_lte_pte()
+        fdata = pjoin(folder, 'lte-pte.nii.gz')
+        fbval = pjoin(folder, 'lte-pte.bval')
+        fbvec = pjoin(folder, 'lte-pte.bvec')
+        fmask = pjoin(folder, 'mask.nii.gz')
+        return fdata, fbval, fbvec, fmask
     if name == 'fury_surface':
         files, folder = fetch_fury_surface()
         surface_name = pjoin(folder, '100307_white_lh.vtk')
         return surface_name
+    if name == 'histo_resdnn_weights':
+        files, folder = fetch_resdnn_weights()
+        wraw = pjoin(folder, 'resdnn_weights_mri_2018.h5')
+        return wraw
+    if name == 'DiB_70_lte_pte_ste':
+        _, folder = fetch_DiB_70_lte_pte_ste()
+        fdata = pjoin(folder, 'DiB_70_lte_pte_ste.nii.gz')
+        fbval = pjoin(folder, 'bval_DiB_70_lte_pte_ste.bval')
+        fbvec = pjoin(folder, 'bvec_DiB_70_lte_pte_ste.bvec')
+        fmask = pjoin(folder, 'DiB_mask.nii.gz')
+        return fdata, fbval, fbvec, fmask
+    if name == 'DiB_217_lte_pte_ste':
+        _, folder = fetch_DiB_217_lte_pte_ste()
+        fdata_1 = pjoin(folder, 'DiB_217_lte_pte_ste_1.nii.gz')
+        fdata_2 = pjoin(folder, 'DiB_217_lte_pte_ste_2.nii.gz')
+        fbval = pjoin(folder, 'bval_DiB_217_lte_pte_ste.bval')
+        fbvec = pjoin(folder, 'bvec_DiB_217_lte_pte_ste.bvec')
+        fmask = pjoin(folder, 'DiB_mask.nii.gz')
+        return fdata_1, fdata_2, fbval, fbvec, fmask
 
 
 def read_qtdMRI_test_retest_2subjects():
@@ -859,7 +974,7 @@ def read_stanford_pve_maps():
     img_pve_csf = nib.load(f_pve_csf)
     img_pve_gm = nib.load(f_pve_gm)
     img_pve_wm = nib.load(f_pve_wm)
-    return (img_pve_csf, img_pve_gm, img_pve_wm)
+    return img_pve_csf, img_pve_gm, img_pve_wm
 
 
 def read_taiwan_ntu_dsi():
@@ -917,7 +1032,7 @@ def fetch_tissue_data():
     fname_list = ['t1_brain.nii.gz', 't1_brain_denoised.nii.gz',
                   'power_map.nii.gz']
 
-    if not os.path.exists(folder):
+    if not op.exists(folder):
         _log('Creating new directory %s' % folder)
         os.makedirs(folder)
         msg = 'Downloading 3 Nifti1 images (9.3MB)...'
@@ -1194,17 +1309,17 @@ fetch_cenir_multib.__doc__ += CENIR_notes
 read_cenir_multib.__doc__ += CENIR_notes
 
 
-def read_bundles_2_subjects(subj_id='subj_1', metrics=['fa'],
-                            bundles=['af.left', 'cst.right', 'cc_1']):
+def read_bundles_2_subjects(subj_id='subj_1', metrics=('fa',),
+                            bundles=('af.left', 'cst.right', 'cc_1')):
     r"""Read images and streamlines from 2 subjects of the SNAIL dataset.
 
     Parameters
     ----------
     subj_id : string
         Either ``subj_1`` or ``subj_2``.
-    metrics : list
+    metrics : array-like
         Either ['fa'] or ['t1'] or ['fa', 't1']
-    bundles : list
+    bundles : array-like
         E.g., ['af.left', 'cst.right', 'cc_1']. See all the available bundles
         in the ``exp_bundles_maps/bundles_2_subjects`` directory of your
         ``$HOME/.dipy`` folder.
@@ -1385,3 +1500,397 @@ def get_target_tractogram_hcp():
                   'streamlines.trk')
 
     return file1
+
+
+def read_qte_lte_pte():
+    """Read q-space trajectory encoding data with linear and planar tensor
+    encoding.
+
+    Returns
+    -------
+    data_img : nibabel.nifti1.Nifti1Image
+        dMRI data image.
+    mask_img : nibabel.nifti1.Nifti1Image
+        Brain mask image.
+    gtab : dipy.core.gradients.GradientTable
+        Gradient table.
+    """
+    fdata, fbval, fbvec, fmask = get_fnames('qte_lte_pte')
+    data_img = nib.load(fdata)
+    mask_img = nib.load(fmask)
+    bvals = np.loadtxt(fbval)
+    bvecs = np.loadtxt(fbvec)
+    btens = np.array(['LTE' for i in range(61)] + ['PTE' for i in range(61)])
+    gtab = gradient_table(bvals, bvecs, btens=btens)
+    return data_img, mask_img, gtab
+
+
+def read_DiB_70_lte_pte_ste():
+    """Read q-space trajectory encoding data with 70 between linear, planar,
+    and spherical tensor encoding measurements.
+
+    Returns
+    -------
+    data_img : nibabel.nifti1.Nifti1Image
+        dMRI data image.
+    mask_img : nibabel.nifti1.Nifti1Image
+        Brain mask image.
+    gtab : dipy.core.gradients.GradientTable
+        Gradient table.
+    """
+    fdata, fbval, fbvec, fmask = get_fnames('DiB_70_lte_pte_ste')
+    data_img = nib.load(fdata)
+    mask_img = nib.load(fmask)
+    bvals = np.loadtxt(fbval)
+    bvecs = np.loadtxt(fbvec)
+    btens = np.array(['LTE' for i in range(1)] +
+                     ['LTE' for i in range(4)] +
+                     ['PTE' for i in range(3)] +
+                     ['STE' for i in range(3)] +
+                     ['STE' for i in range(4)] +
+                     ['LTE' for i in range(8)] +
+                     ['PTE' for i in range(5)] +
+                     ['STE' for i in range(5)] +
+                     ['LTE' for i in range(21)] +
+                     ['PTE' for i in range(10)] +
+                     ['STE' for i in range(6)])
+    gtab = gradient_table(bvals, bvecs, btens=btens)
+    return data_img, mask_img, gtab
+
+
+def read_DiB_217_lte_pte_ste():
+    """Read q-space trajectory encoding data with 217 between linear,
+    planar, and spherical tensor encoding.
+
+    Returns
+    -------
+    data_img : nibabel.nifti1.Nifti1Image
+        dMRI data image.
+    mask_img : nibabel.nifti1.Nifti1Image
+        Brain mask image.
+    gtab : dipy.core.gradients.GradientTable
+        Gradient table.
+    """
+    fdata_1, fdata_2, fbval, fbvec, fmask = get_fnames('DiB_217_lte_pte_ste')
+    _, folder = fetch_DiB_217_lte_pte_ste()
+    if op.isfile(pjoin(folder, 'DiB_217_lte_pte_ste.nii.gz')):
+        data_img = nib.load(pjoin(folder, 'DiB_217_lte_pte_ste.nii.gz'))
+    else:
+        data_1, affine = load_nifti(fdata_1)
+        data_2, _ = load_nifti(fdata_2)
+        data = np.concatenate((data_1, data_2), axis=3)
+        save_nifti(pjoin(folder, 'DiB_217_lte_pte_ste.nii.gz'), data, affine)
+        data_img = nib.load(pjoin(folder, 'DiB_217_lte_pte_ste.nii.gz'))
+    mask_img = nib.load(fmask)
+    bvals = np.loadtxt(fbval)
+    bvecs = np.loadtxt(fbvec)
+    btens = np.array(['LTE' for i in range(13)] +
+                     ['LTE' for i in range(10)] +
+                     ['PTE' for i in range(10)] +
+                     ['STE' for i in range(10)] +
+                     ['LTE' for i in range(10)] +
+                     ['PTE' for i in range(10)] +
+                     ['STE' for i in range(10)] +
+                     ['LTE' for i in range(16)] +
+                     ['PTE' for i in range(16)] +
+                     ['STE' for i in range(10)] +
+                     ['LTE' for i in range(46)] +
+                     ['PTE' for i in range(46)] +
+                     ['STE' for i in range(10)])
+    gtab = gradient_table(bvals, bvecs, btens=btens)
+    return data_img, mask_img, gtab
+
+
+def extract_example_tracts(out_dir):
+    """ Extract 5 'AF_L','CST_R' and 'CC_ForcepsMajor' trk files in out_dir
+    folder.
+
+    Parameters
+    ----------
+    out_dir : str
+        Folder in which to extract the files.
+
+    """
+
+    fname = get_fnames('minimal_bundles')
+
+    with zipfile.ZipFile(fname, 'r') as zip_obj:
+        zip_obj.extractall(out_dir)
+
+
+def read_five_af_bundles():
+    """ Load 5 small left arcuate fasciculus bundles.
+
+    Returns
+    -------
+    bundles: list of ArraySequence
+        List with loaded bundles.
+
+    """
+
+    subjects = ['sub_1', 'sub_2', 'sub_3', 'sub_4', 'sub_5']
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        extract_example_tracts(temp_dir)
+
+        bundles = []
+        for sub in subjects:
+            fname = pjoin(temp_dir, sub, 'AF_L.trk')
+            bundle_obj = load_trk(fname, 'same', bbox_valid_check=False)
+            bundles.append(bundle_obj.streamlines)
+
+    return bundles
+
+
+def to_bids_description(path, fname='dataset_description.json',
+                        BIDSVersion="1.4.0", **kwargs):
+    """Dumps a dict into a bids description at the given location"""
+    kwargs.update({"BIDSVersion": BIDSVersion})
+    desc_file = op.join(path, fname)
+    with open(desc_file, 'w') as outfile:
+        json.dump(kwargs, outfile)
+
+
+def fetch_hcp(subjects,
+              hcp_bucket='hcp-openaccess',
+              profile_name="hcp",
+              path=None,
+              study='HCP_1200',
+              aws_access_key_id=None,
+              aws_secret_access_key=None):
+    """
+    Fetch HCP diffusion data and arrange it in a manner that resembles the
+    BIDS [1]_ specification.
+
+    Parameters
+    ----------
+    subjects : list
+        Each item is an integer, identifying one of the HCP subjects
+    hcp_bucket : string, optional
+        The name of the HCP S3 bucket. Default: "hcp-openaccess"
+    profile_name : string, optional
+        The name of the AWS profile used for access. Default: "hcp"
+    path : string, optional
+        Path to save files into. Default: '~/.dipy'
+    study : string, optional
+        Which HCP study to grab. Default: 'HCP_1200'
+    aws_access_key_id : string, optional
+        AWS credentials to HCP AWS S3. Will only be used if `profile_name` is
+        set to False.
+    aws_secret_access_key : string, optional
+        AWS credentials to HCP AWS S3. Will only be used if `profile_name` is
+        set to False.
+
+    Returns
+    -------
+    dict with remote and local names of these files,
+    path to BIDS derivative dataset
+
+    Notes
+    -----
+    To use this function with its default setting, you need to have a
+    file '~/.aws/credentials', that includes a section:
+
+    [hcp]
+    AWS_ACCESS_KEY_ID=XXXXXXXXXXXXXXXX
+    AWS_SECRET_ACCESS_KEY=XXXXXXXXXXXXXXXX
+
+    The keys are credentials that you can get from HCP
+    (see https://wiki.humanconnectome.org/display/PublicData/How+To+Connect+to+Connectome+Data+via+AWS)  # noqa
+
+    Local filenames are changed to match our expected conventions.
+
+    .. [1] Gorgolewski et al. (2016). The brain imaging data structure,
+           a format for organizing and describing outputs of neuroimaging
+           experiments. Scientific Data, 3::160044. DOI: 10.1038/sdata.2016.44.
+    """
+    if not has_boto3:
+        raise ValueError("'fetch_hcp' requires boto3 and it is"
+                         " not currently installed. Please install"
+                         "it using `pip install boto3`. ")
+
+    if profile_name:
+        boto3.setup_default_session(profile_name=profile_name)
+    elif aws_access_key_id is not None and aws_secret_access_key is not None:
+        boto3.setup_default_session(
+            aws_access_key_id=aws_access_key_id,
+            aws_secret_access_key=aws_secret_access_key)
+    else:
+        raise ValueError("Must provide either a `profile_name` or ",
+                         "both `aws_access_key_id` and ",
+                         "`aws_secret_access_key` as input to 'fetch_hcp'")
+
+    s3 = boto3.resource('s3')
+    bucket = s3.Bucket(hcp_bucket)
+
+    if path is None:
+        if not op.exists(dipy_home):
+            os.mkdir(dipy_home)
+        my_path = dipy_home
+    else:
+        my_path = path
+
+    base_dir = pjoin(my_path, study, 'derivatives', 'hcp_pipeline')
+
+    if not op.exists(base_dir):
+        os.makedirs(base_dir, exist_ok=True)
+
+    data_files = {}
+    # If user provided incorrect input, these are typical failures that
+    # are easy to recover from:
+    if isinstance(subjects, int) or isinstance(subjects, str):
+        subjects = [subjects]
+
+    for subject in subjects:
+        sub_dir = pjoin(base_dir, f'sub-{subject}')
+        if not op.exists(sub_dir):
+            os.makedirs(pjoin(sub_dir, 'dwi'), exist_ok=True)
+            os.makedirs(pjoin(sub_dir, 'anat'), exist_ok=True)
+        data_files[pjoin(sub_dir, 'dwi', f'sub-{subject}_dwi.bval')] =\
+            f'{study}/{subject}/T1w/Diffusion/bvals'
+        data_files[pjoin(sub_dir, 'dwi', f'sub-{subject}_dwi.bvec')] =\
+            f'{study}/{subject}/T1w/Diffusion/bvecs'
+        data_files[pjoin(sub_dir, 'dwi', f'sub-{subject}_dwi.nii.gz')] =\
+            f'{study}/{subject}/T1w/Diffusion/data.nii.gz'
+        data_files[pjoin(sub_dir, 'anat', f'sub-{subject}_T1w.nii.gz')] =\
+            f'{study}/{subject}/T1w/T1w_acpc_dc.nii.gz'
+        data_files[pjoin(sub_dir, 'anat',
+                           f'sub-{subject}_aparc+aseg_seg.nii.gz')] =\
+            f'{study}/{subject}/T1w/aparc+aseg.nii.gz'
+
+    download_files = {}
+    for k in data_files.keys():
+        if not op.exists(k):
+            download_files[k] = data_files[k]
+    if len(download_files.keys()):
+        with tqdm(total=len(download_files.keys())) as pbar:
+            for k in download_files.keys():
+                pbar.set_description_str(f"Downloading {k}")
+                bucket.download_file(download_files[k], k)
+                pbar.update()
+
+    # Create the BIDS dataset description file text
+    hcp_acknowledgements = """Data were provided by the Human Connectome Project, WU-Minn Consortium (Principal Investigators: David Van Essen and Kamil Ugurbil; 1U54MH091657) funded by the 16 NIH Institutes and Centers that support the NIH Blueprint for Neuroscience Research; and by the McDonnell Center for Systems Neuroscience at Washington University.""",  # noqa
+    to_bids_description(pjoin(my_path, study),
+                        **{"Name": study,
+                           "Acknowledgements": hcp_acknowledgements,
+                           "Subjects": subjects})
+
+    # Create the BIDS derivatives description file text
+    to_bids_description(base_dir,
+                        **{"Name": study,
+                           "Acknowledgements": hcp_acknowledgements,
+                           "PipelineDescription": {'Name': 'hcp_pipeline'}})
+
+    return data_files, pjoin(my_path, study)
+
+
+def fetch_hbn(subjects, path=None):
+    """
+    Fetch preprocessed data from the Healthy Brain Network POD2 study [1, 2]_.
+
+    Parameters
+    ----------
+    subjects : list
+        Identifiers of the subjects to download.
+        For example: ["NDARAA948VFH", "NDAREK918EC2"].
+
+    path : string, optional
+        Path to save files into. Default: '~/.dipy'
+
+    Returns
+    -------
+    dict with remote and local names of these files,
+    path to BIDS derivative dataset
+
+    Notes
+    -----
+
+    .. [1] Alexander LM, Escalera J, Ai L, et al. An open resource for
+        transdiagnostic research in pediatric mental health and learning
+        disorders. Sci Data. 2017;4:170181.
+
+    .. [2] Richie-Halford A, Cieslak M, Ai L, et al. An analysis-ready and
+        quality controlled resource for pediatric brain white-matter research.
+        Scientific Data. 2022;9(1):1-27.
+
+    """
+
+    if has_boto3:
+        from botocore import UNSIGNED
+        from botocore.client import Config
+    else:
+        TripWire("The `fetch_hbn` function requires the boto3" +
+                 " library, but that is not installed.")
+
+    # Anonymous access:
+    client = boto3.client('s3', config=Config(signature_version=UNSIGNED))
+
+    if path is None:
+        if not op.exists(dipy_home):
+            os.mkdir(dipy_home)
+        my_path = dipy_home
+    else:
+        my_path = path
+
+    base_dir = op.join(my_path, "HBN", 'derivatives', 'qsiprep')
+
+    if not os.path.exists(base_dir):
+        os.makedirs(base_dir, exist_ok=True)
+
+    data_files = {}
+
+    # If user provided incorrect input, these are typical failures that
+    # are easy to recover from:
+    if isinstance(subjects, int) or isinstance(subjects, str):
+        subjects = [subjects]
+
+    for subject in subjects:
+        initial_query = client.list_objects(
+            Bucket="fcp-indi",
+            Prefix=f"data/Projects/HBN/BIDS_curated/sub-{subject}/")
+        ses = initial_query.get('Contents', None)
+        if ses is None:
+            raise ValueError(f"Could not find data for subject {subject}")
+        else:
+            ses = ses[0]["Key"].split('/')[5]
+
+        query = client.list_objects(
+            Bucket="fcp-indi",
+            Prefix=f"data/Projects/HBN/BIDS_curated/derivatives/qsiprep/sub-{subject}/{ses}/")  # noqa
+        query_content = query.get('Contents', None)
+        if query_content is None:
+            raise ValueError(f"Could not find derivatives data for subject {subject}")
+        file_list = [kk["Key"] for kk in query["Contents"]]
+        sub_dir = op.join(base_dir, f'sub-{subject}')
+        ses_dir = op.join(sub_dir, ses)
+        if not os.path.exists(sub_dir):
+            os.makedirs(os.path.join(ses_dir, 'dwi'), exist_ok=True)
+            os.makedirs(os.path.join(ses_dir, 'anat'), exist_ok=True)
+        for remote in file_list:
+            full = remote.split("Projects")[-1][1:].replace("/BIDS_curated", "")
+            local = op.join(dipy_home, full)
+            data_files[local] = remote
+
+    download_files = {}
+    for k in data_files.keys():
+        if not op.exists(k):
+            download_files[k] = data_files[k]
+    if len(download_files.keys()):
+        with tqdm(total=len(download_files.keys())) as pbar:
+            for k in download_files.keys():
+                pbar.set_description_str(f"Downloading {k}")
+                client.download_file("fcp-indi", download_files[k], k)
+                pbar.update()
+
+    # Create the BIDS dataset description file text
+    to_bids_description(op.join(my_path, "HBN"),
+                        **{"Name": "HBN",
+                           "Subjects": subjects})
+
+    # Create the BIDS derivatives description file text
+    to_bids_description(base_dir,
+                        **{"Name": "HBN",
+                           "PipelineDescription": {'Name': 'qsiprep'}})
+
+    return data_files, pjoin(my_path, "HBN")
