@@ -47,7 +47,7 @@ def _image_tv(x, axis=0, n_points=3):
     ptv = np.absolute(xs[:, (n_points+1):(-n_points-1)] -
                       xs[:, (n_points+2):(-n_points)])
     ntv = np.absolute(xs[:, (n_points+1):(-n_points-1)] -
-                      xs[:, (n_points):(-n_points-2)])
+                      xs[:, n_points:(-n_points-2)])
     for n in range(1, n_points):
         ptv = ptv + np.absolute(xs[:, (n_points+1+n):(-n_points-1+n)] -
                                 xs[:, (n_points+2+n):(-n_points+n)])
@@ -261,8 +261,8 @@ def gibbs_removal(vol, slice_axis=2, n_points=3, inplace=True,
     num_processes : int or None, optional
         Split the calculation to a pool of children processes. This only
         applies to 3D or 4D `data` arrays. Default is 1. If < 0 the maximal
-        number of cores minus |num_processes + 1| is used (enter -1 to use as
-        many cores as possible). 0 raises an error.
+        number of cores minus ``num_processes + 1`` is used (enter -1 to use
+        as many cores as possible). 0 raises an error.
 
     Returns
     -------
