@@ -1,10 +1,10 @@
 import numpy as np
 import scipy.special as sps
-from numpy.testing import (run_module_suite,
-                           assert_,
+from numpy.testing import (assert_,
                            assert_equal,
                            assert_raises,
-                           assert_array_almost_equal)
+                           assert_array_almost_equal,
+                           assert_warns)
 from dipy.denoise.localpca import (localpca, mppca, genpca, _pca_classifier)
 from dipy.sims.voxel import multi_tensor
 from dipy.core.gradients import gradient_table, generate_bvecs
@@ -242,7 +242,7 @@ def test_phantom():
 def test_lpca_ill_conditioned():
     DWI, sigma = rfiw_phantom(gtab, snr=30)
     for patch_radius in [1, [1, 1, 1]]:
-        assert_raises(ValueError, localpca, DWI, sigma,
+        assert_warns(UserWarning, localpca, DWI, sigma,
                       patch_radius=patch_radius)
 
 
@@ -285,8 +285,8 @@ def test_pca_classifier():
     var, c = _pca_classifier(L, 125)
     std = np.sqrt(var)
 
-    # Expected number of signal components is 0 because phantom only has one
-    # voxel type and that information is campured by the mean of X.
+    # Expected number of signal components is 0 because the phantom only has
+    # one voxel type and that information is captured by the mean of X.
     # Therefore, expected noise components should be equal to size of L.
     # To allow some margin of error let's assess if c is higher than
     # L.size - 3.
@@ -322,8 +322,8 @@ def test_mppca_returned_sigma():
     std_error = abs(msigma - std_gt)/std_gt * 100
     assert_(std_error < 5)
 
-    # Case that sigma is inputed (sigma outputed should be the same as the one
-    # inputed)
+    # Case that sigma is inputted (sigma outputted should be the same as the
+    # one inputted)
     DWIden1, rsigma = genpca(DWInoise, sigma=sigma, tau_factor=None,
                              patch_radius=2, return_sigma=True)
     assert_array_almost_equal(rsigma, sigma)
@@ -332,7 +332,3 @@ def test_mppca_returned_sigma():
     rmse_den = np.sum(np.abs(DWIden1 - DWIden0)) / np.sum(np.abs(DWIden0))
     rmse_ref = np.sum(np.abs(DWIden1 - DWIgt)) / np.sum(np.abs(DWIgt))
     assert_(rmse_den < rmse_ref)
-
-
-if __name__ == '__main__':
-    run_module_suite()
