@@ -146,6 +146,10 @@ def gen_dirac(m, n, theta, phi, legacy=True):
         The polar (colatitudinal) coordinate.
     phi : float [0, 2*pi]
         The azimuthal (longitudinal) coordinate.
+    legacy: bool, optional
+        If true, uses DIPY's legacy descoteaux07 implementation (where |m|
+        is used for m < 0). Else, implements the basis as defined in
+        Descoteaux et al. 2007 (without the absolute value).
 
     See Also
     --------
@@ -164,7 +168,7 @@ def gen_dirac(m, n, theta, phi, legacy=True):
 def spherical_harmonics(m, n, theta, phi, use_scipy=True):
     """Compute spherical harmonics.
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -224,7 +228,7 @@ def real_sph_harm(m, n, theta, phi):
         $Y^0_n$                     if m = 0
         Real($Y^|m|_n$) * sqrt(2)   if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -259,7 +263,7 @@ def real_sh_tournier_from_index(m, n, theta, phi, legacy=True):
         $Y^0_n$                      if m = 0
         Imag($Y^|m|_n$) * sqrt(2)    if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -313,7 +317,7 @@ def real_sh_descoteaux_from_index(m, n, theta, phi, legacy=True):
         $Y^0_n$                      if m = 0
         Real($Y^m_n$) * sqrt(2)      if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -367,7 +371,7 @@ def real_sh_tournier(sh_order, theta, phi,
         $Y^0_n$                      if m = 0
         Imag($Y^|m|_n$) * sqrt(2)    if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -425,7 +429,7 @@ def real_sh_descoteaux(sh_order, theta, phi,
         $Y^0_n$                      if m = 0
         Real($Y^m_n$) * sqrt(2)      if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -482,7 +486,7 @@ def real_sym_sh_mrtrix(sh_order, theta, phi):
         $Y^0_n$             if m = 0
         Imag($Y^|m|_n$)     if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -535,7 +539,7 @@ def real_sym_sh_basis(sh_order, theta, phi):
         $Y^0_n$                     if m = 0
         Real($Y^|m|_n$) * sqrt(2)   if m < 0
 
-    This may take scalar or array arguments. The inputs will be broadcasted
+    This may take scalar or array arguments. The inputs will be broadcast
     against each other.
 
     Parameters
@@ -615,7 +619,7 @@ def sph_harm_ind_list(sh_order, full_basis=False):
         offset = offset + 2 * ii + 1
 
     # makes the arrays ncoef by 1, allows for easy broadcasting later in code
-    return (m_list, n_list)
+    return m_list, n_list
 
 
 def order_from_ncoef(ncoef, full_basis=False):
@@ -713,7 +717,7 @@ def _gfa_sh(coef, sh0_index=0):
     """
     coef_sq = coef**2
     numer = coef_sq[..., sh0_index]
-    denom = (coef_sq).sum(-1)
+    denom = coef_sq.sum(-1)
     # The sum of the square of the coefficients being zero is the same as all
     # the coefficients being zero
     allzero = denom == 0
@@ -872,7 +876,7 @@ class SphHarmFit(OdfFit):
     def shm_coeff(self):
         """The spherical harmonic coefficients of the odf
 
-        Make this a property for now, if there is a usecase for modifying
+        Make this a property for now, if there is a use case for modifying
         the coefficients we can add a setter or expose the coefficients more
         directly
         """
@@ -1026,7 +1030,7 @@ def bootstrap_data_array(data, H, R, permute=None):
     data must be normalized, ie 0 < data <= 1
 
     This function, and the bootstrap_data_voxel function, calculate
-    residual-bootsrap samples given a Hat matrix and a Residual matrix. These
+    residual-bootstrap samples given a Hat matrix and a Residual matrix. These
     samples can be used for non-parametric statistics or for bootstrap
     probabilistic tractography:
 
@@ -1077,7 +1081,7 @@ class ResidualBootstrapWrapper(object):
         Given some linear model described by B, the design matrix, and a
         signal_object, returns an object which can sample the residual
         bootstrap distribution of the signal. We assume that the signals are
-        normalized so we clip the bootsrap samples to be between `min_signal`
+        normalized so we clip the bootstrap samples to be between `min_signal`
         and 1.
 
         Parameters
