@@ -1,15 +1,12 @@
 import numpy as np
 from numpy.testing import (assert_equal,
                            assert_almost_equal,
-                           run_module_suite,
-                           assert_array_equal,
                            assert_raises)
 from dipy.data import get_fnames, dsi_voxels, default_sphere
 from dipy.reconst.dsi import DiffusionSpectrumModel
 from dipy.reconst.odf import gfa
 from dipy.direction.peaks import peak_directions
 from dipy.sims.voxel import sticks_and_ball
-from dipy.core.sphere import Sphere
 from dipy.core.gradients import gradient_table
 from dipy.core.subdivide_octahedron import create_unit_sphere
 from dipy.core.sphere_stats import angular_similarity
@@ -116,7 +113,3 @@ def sticks_and_ball_dummies(gtab):
                                 fractions=[0, 0, 0], snr=None)
     sb_dummies['isotropic'] = (S, sticks)
     return sb_dummies
-
-
-if __name__ == '__main__':
-    run_module_suite()
