@@ -14,8 +14,8 @@ References
 import warnings
 import numpy as np
 from numpy.testing import (assert_array_equal, assert_array_almost_equal,
-                           assert_raises, assert_array_less, run_module_suite,
-                           assert_, assert_equal)
+                           assert_raises, assert_array_less, assert_,
+                           assert_equal)
 from dipy.testing import assert_greater_equal
 import pytest
 
@@ -62,8 +62,12 @@ def setup_module():
     ivim_params_trr[0, 0, 0] = ivim_params_trr[0, 1, 0] = params_trr
     ivim_params_trr[1, 0, 0] = ivim_params_trr[1, 1, 0] = params_trr
 
-    ivim_model_trr = IvimModel(gtab, fit_method='trr')
-    ivim_model_one_stage = IvimModel(gtab, fit_method='trr')
+    msg = "Bounds for this fit have been set from experiments .*"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        ivim_model_trr = IvimModel(gtab, fit_method='trr')
+        ivim_model_one_stage = IvimModel(gtab, fit_method='trr')
+
     ivim_fit_single = ivim_model_trr.fit(data_single)
     ivim_fit_multi = ivim_model_trr.fit(data_multi)
 
@@ -74,8 +78,8 @@ def setup_module():
                             120., 140., 160., 180., 200., 300., 400.,
                             500., 600., 700., 800., 900., 1000.])
 
-    _ = generate_bvecs(N)  # bvecs_no_b0
-    gtab_no_b0 = gradient_table(bvals_no_b0, bvecs.T, b0_threshold=0)
+    with pytest.warns(UserWarning):
+        gtab_no_b0 = gradient_table(bvals_no_b0, bvecs.T, b0_threshold=0)
 
     bvals_with_multiple_b0 = np.array([0., 0., 0., 0., 40., 60., 80., 100.,
                                        120., 140., 160., 180., 200., 300.,
@@ -100,7 +104,10 @@ def setup_module():
         1, 0, 0] = noisy_multi[1, 1, 0] = noisy_single
     noisy_multi[0, 0, 0] = data_single
 
-    ivim_model_VP = IvimModel(gtab, fit_method='VarPro')
+    msg = "Bounds for this fit have been set from experiments .*"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        ivim_model_VP = IvimModel(gtab, fit_method='VarPro')
     f_VP, D_star_VP, D_VP = 0.13, 0.0088, 0.000921
     # params for a single voxel
     params_VP = np.array([f, D_star, D])
@@ -131,7 +138,7 @@ def test_single_voxel_fit():
 
     In the two stage fitting routine, initially we fit the signal
     values for bvals less than the specified split_b using the
-    TensorModel and get an intial guess for f and D. Then, using
+    TensorModel and get an initial guess for f and D. Then, using
     these parameters we fit the entire data for all bvalues.
     """
     est_signal = ivim_prediction(ivim_fit_single.model_params, gtab)
@@ -321,7 +328,11 @@ def test_multiple_b0():
     # Single voxel data
     data_single = signal[0]
 
-    ivim_model_multiple_b0 = IvimModel(gtab_with_multiple_b0, fit_method='trr')
+    msg = "Bounds for this fit have been set from experiments .*"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        ivim_model_multiple_b0 = IvimModel(gtab_with_multiple_b0,
+                                           fit_method='trr')
 
     ivim_model_multiple_b0.fit(data_single)
     # Test if all signals are positive
@@ -340,14 +351,18 @@ def test_noisy_fit():
     around 135 and D and D_star values are equal. Hence doing a test based on
     Scipy version.
     """
-    model_one_stage = IvimModel(gtab, fit_method='trr')
+    msg = "Bounds for this fit have been set from experiments .*"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        model_one_stage = IvimModel(gtab, fit_method='trr')
+
     with warnings.catch_warnings(record=True) as w:
         fit_one_stage = model_one_stage.fit(noisy_single)
         assert_equal(len(w), 3)
         for l_w in w:
             assert_(issubclass(l_w.category, UserWarning))
         assert_("" in str(w[0].message))
-        assert_("x0 obtained from linear fitting is not feasibile" in
+        assert_("x0 obtained from linear fitting is not feasible" in
                 str(w[0].message))
         assert_("x0 is unfeasible" in str(w[1].message))
         assert_("Bounds are violated for leastsq fitting" in str(w[2].message))
@@ -423,7 +438,11 @@ def test_fit_one_stage():
     """
     Test to check the results for the one_stage linear fit.
     """
-    model = IvimModel(gtab, two_stage=False)
+    msg = "Bounds for this fit have been set from experiments .*"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        model = IvimModel(gtab, two_stage=False)
+
     fit = model.fit(data_single)
     linear_fit_params = [9.88834140e+02, 1.19707191e-01, 7.91176970e-03,
                          9.30095210e-04]
@@ -451,7 +470,7 @@ def test_leastsq_failing():
         assert_greater_equal(len(w), 3)
         u_warn = [l_w for l_w in w if issubclass(l_w.category, UserWarning)]
         assert_greater_equal(len(u_warn), 3)
-        message = ["x0 obtained from linear fitting is not feasibile",
+        message = ["x0 obtained from linear fitting is not feasible",
                    "x0 is unfeasible",
                    "Bounds are violated for leastsq fitting"]
         assert_greater_equal(len([lw for lw in u_warn for m in message
@@ -505,7 +524,3 @@ def test_D_vp():
     """
     ivim_fit_VP = ivim_model_VP.fit(data_single)
     assert_array_almost_equal(ivim_fit_VP.D, D_VP, decimal=4)
-
-
-if __name__ == '__main__':
-    run_module_suite()
