@@ -1,17 +1,17 @@
 # Tests for shore fitting
+import warnings
 from math import factorial
 
 import numpy as np
+import numpy.testing as npt
 
 from scipy.special import genlaguerre, gamma
 
 from dipy.data import get_gtab_taiwan_dsi
+from dipy.reconst.shm import descoteaux07_legacy_msg
 from dipy.reconst.shore import ShoreModel
 from dipy.sims.voxel import multi_tensor
 
-from numpy.testing import (assert_almost_equal,
-                           assert_equal,
-                           run_module_suite)
 import pytest
 from dipy.utils.optpkg import optional_package
 cvxpy, have_cvxpy, _ = optional_package("cvxpy")
@@ -39,6 +39,14 @@ def setup():
     data.lambdaL = 1e-12
 
 
+def test_shore_error():
+    data.gtab = get_gtab_taiwan_dsi()
+    npt.assert_raises(ValueError, ShoreModel, data.gtab, radial_order=-4)
+    npt.assert_raises(ValueError, ShoreModel, data.gtab, radial_order=7)
+    npt.assert_raises(ValueError, ShoreModel, data.gtab, constrain_e0=False,
+                      positive_constraint=True)
+
+
 @needs_cvxpy
 def test_shore_positive_constrain():
     asm = ShoreModel(data.gtab,
@@ -50,17 +58,25 @@ def test_shore_positive_constrain():
                      positive_constraint=True,
                      pos_grid=11,
                      pos_radius=20e-03)
-    asmfit = asm.fit(data.S)
-    eap = asmfit.pdf_grid(11, 20e-03)
-    assert_almost_equal(eap[eap < 0].sum(), 0, 3)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        asmfit = asm.fit(data.S)
+        eap = asmfit.pdf_grid(11, 20e-03)
+    npt.assert_almost_equal(eap[eap < 0].sum(), 0, 3)
 
 
 def test_shore_fitting_no_constrain_e0():
     asm = ShoreModel(data.gtab, radial_order=data.radial_order,
                      zeta=data.zeta, lambdaN=data.lambdaN,
                      lambdaL=data.lambdaL)
-    asmfit = asm.fit(data.S)
-    assert_almost_equal(compute_e0(asmfit), 1)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        asmfit = asm.fit(data.S)
+    npt.assert_almost_equal(compute_e0(asmfit), 1)
 
 
 @needs_cvxpy
@@ -69,8 +85,12 @@ def test_shore_fitting_constrain_e0():
                      zeta=data.zeta, lambdaN=data.lambdaN,
                      lambdaL=data.lambdaL,
                      constrain_e0=True)
-    asmfit = asm.fit(data.S)
-    assert_almost_equal(compute_e0(asmfit), 1)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        asmfit = asm.fit(data.S)
+    npt.assert_almost_equal(compute_e0(asmfit), 1)
 
 
 def compute_e0(shorefit):
