@@ -1,12 +1,12 @@
+import warnings
+
 import numpy as np
-from dipy.data import default_sphere, get_3shell_gtab, get_isbi2013_2shell_gtab
-from dipy.reconst.shore import ShoreModel
-from dipy.reconst.shm import sh_to_sf
+import numpy.testing as npt
+from dipy.data import default_sphere, get_isbi2013_2shell_gtab, get_3shell_gtab
+from dipy.reconst.shore import ShoreModel, shore_matrix
+from dipy.reconst.shm import sh_to_sf, descoteaux07_legacy_msg
 from dipy.direction.peaks import peak_directions
 from dipy.reconst.odf import gfa
-from numpy.testing import (assert_equal,
-                           assert_almost_equal,
-                           run_module_suite)
 from dipy.sims.voxel import sticks_and_ball
 from dipy.core.subdivide_octahedron import create_unit_sphere
 from dipy.core.sphere_stats import angular_similarity
@@ -27,23 +27,43 @@ def test_shore_odf():
     asm = ShoreModel(gtab, radial_order=6,
                      zeta=700, lambdaN=1e-8, lambdaL=1e-8)
     # repulsion724
-    asmfit = asm.fit(data)
-    odf = asmfit.odf(sphere)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        asmfit = asm.fit(data)
+        odf = asmfit.odf(sphere)
     odf_sh = asmfit.odf_sh()
-    odf_from_sh = sh_to_sf(odf_sh, sphere, 6, basis_type=None,
-                           legacy=True)
-    assert_almost_equal(odf, odf_from_sh, 10)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        odf_from_sh = sh_to_sf(odf_sh, sphere, 6, basis_type=None,
+                               legacy=True)
+    npt.assert_almost_equal(odf, odf_from_sh, 10)
+
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        expected_phi = shore_matrix(radial_order=6, zeta=700, gtab=gtab)
+    npt.assert_array_almost_equal(np.dot(expected_phi, asmfit.shore_coeff),
+                                  asmfit.fitted_signal())
 
     directions, _, _ = peak_directions(odf, sphere, .35, 25)
-    assert_equal(len(directions), 2)
-    assert_almost_equal(
+    npt.assert_equal(len(directions), 2)
+    npt.assert_almost_equal(
         angular_similarity(directions, golden_directions), 2, 1)
 
     # 5 subdivisions
-    odf = asmfit.odf(sphere2)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        odf = asmfit.odf(sphere2)
     directions, _, _ = peak_directions(odf, sphere2, .35, 25)
-    assert_equal(len(directions), 2)
-    assert_almost_equal(
+    npt.assert_equal(len(directions), 2)
+    npt.assert_almost_equal(
         angular_similarity(directions, golden_directions), 2, 1)
 
     sb_dummies = sticks_and_ball_dummies(gtab)
@@ -53,9 +73,9 @@ def test_shore_odf():
         odf = asmfit.odf(sphere2)
         directions, _, _ = peak_directions(odf, sphere2, .35, 25)
         if len(directions) <= 3:
-            assert_equal(len(directions), len(golden_directions))
+            npt.assert_equal(len(directions), len(golden_directions))
         if len(directions) > 3:
-            assert_equal(gfa(odf) < 0.1, True)
+            npt.assert_equal(gfa(odf) < 0.1, True)
 
 
 def test_multivox_shore():
@@ -66,11 +86,11 @@ def test_multivox_shore():
     zeta = 700
     asm = ShoreModel(gtab, radial_order=radial_order,
                      zeta=zeta, lambdaN=1e-8, lambdaL=1e-8)
-    asmfit = asm.fit(data)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore", message=descoteaux07_legacy_msg,
+            category=PendingDeprecationWarning)
+        asmfit = asm.fit(data)
     c_shore = asmfit.shore_coeff
-    assert_equal(c_shore.shape[0:3], data.shape[0:3])
-    assert_equal(np.alltrue(np.isreal(c_shore)), True)
-
-
-if __name__ == '__main__':
-    run_module_suite()
+    npt.assert_equal(c_shore.shape[0:3], data.shape[0:3])
+    npt.assert_equal(np.alltrue(np.isreal(c_shore)), True)
