@@ -15,7 +15,7 @@ import numpy as np
 from dipy.data import get_fnames
 from dipy.io.streamline import load_tractogram
 from dipy.tracking.streamline import Streamlines, set_number_of_points
-from dipy.segment.metric import Metric
+from dipy.segment.metricspeed import Metric
 from dipy.segment.clustering import QuickBundles as QB_New
 from numpy.testing import assert_equal
 
