@@ -1,10 +1,9 @@
 import sys
 import numpy as np
 import pytest
+import warnings
 
-from numpy.testing import (assert_equal,
-                           assert_almost_equal,
-                           run_module_suite)
+from numpy.testing import assert_equal, assert_almost_equal
 from dipy.data import get_fnames
 from dipy.io.streamline import load_tractogram
 from dipy.segment.bundles import RecoBundles
@@ -45,7 +44,10 @@ def test_rb_check_defaults():
                                          model_clust_thr=5.,
                                          reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[rec_labels])
+    msg = "Streamlines do not have the same number of points. *"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[rec_labels])
 
     # check if the bundle is recognized correctly
     if len(f2) == len(rec_labels):
@@ -57,7 +59,9 @@ def test_rb_check_defaults():
                                             model_clust_thr=5.,
                                             reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[refine_labels])
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[refine_labels])
 
     # check if the bundle is recognized correctly
     for row in D:
@@ -75,7 +79,10 @@ def test_rb_disable_slr():
                                          reduction_thr=10,
                                          slr=False)
 
-    D = bundles_distances_mam(f2, f[rec_labels])
+    msg = "Streamlines do not have the same number of points. *"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[rec_labels])
 
     # check if the bundle is recognized correctly
     if len(f2) == len(rec_labels):
@@ -87,7 +94,9 @@ def test_rb_disable_slr():
                                             model_clust_thr=5.,
                                             reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[refine_labels])
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[refine_labels])
 
     # check if the bundle is recognized correctly
     for row in D:
@@ -115,7 +124,11 @@ def test_rb_slr_threads():
                                                      slr=True,
                                                      num_threads=1)
 
-    D = bundles_distances_mam(rec_trans_multi_threads, rec_trans_single_thread)
+    msg = "Streamlines do not have the same number of points. *"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(rec_trans_multi_threads,
+                                  rec_trans_single_thread)
 
     # check if the bundle is recognized correctly
     # multi-threading prevent an exact match
@@ -135,7 +148,10 @@ def test_rb_no_verbose_and_mam():
                                          slr=True,
                                          pruning_distance='mam')
 
-    D = bundles_distances_mam(f2, f[rec_labels])
+    msg = "Streamlines do not have the same number of points. *"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[rec_labels])
 
     # check if the bundle is recognized correctly
     if len(f2) == len(rec_labels):
@@ -147,7 +163,9 @@ def test_rb_no_verbose_and_mam():
                                             model_clust_thr=5.,
                                             reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[refine_labels])
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[refine_labels])
 
     # check if the bundle is recognized correctly
     for row in D:
@@ -166,7 +184,10 @@ def test_rb_clustermap():
                                          model_clust_thr=5.,
                                          reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[rec_labels])
+    msg = "Streamlines do not have the same number of points. *"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[rec_labels])
 
     # check if the bundle is recognized correctly
     if len(f2) == len(rec_labels):
@@ -178,7 +199,9 @@ def test_rb_clustermap():
                                             model_clust_thr=5.,
                                             reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[refine_labels])
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[refine_labels])
 
     # check if the bundle is recognized correctly
     for row in D:
@@ -235,7 +258,10 @@ def test_rb_reduction_mam():
                                          slr_metric='asymmetric',
                                          pruning_distance='mam')
 
-    D = bundles_distances_mam(f2, f[rec_labels])
+    msg = "Streamlines do not have the same number of points. *"
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[rec_labels])
 
     # check if the bundle is recognized correctly
     if len(f2) == len(rec_labels):
@@ -247,13 +273,10 @@ def test_rb_reduction_mam():
                                             model_clust_thr=5.,
                                             reduction_thr=10)
 
-    D = bundles_distances_mam(f2, f[refine_labels])
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", message=msg, category=UserWarning)
+        D = bundles_distances_mam(f2, f[refine_labels])
 
     # check if the bundle is recognized correctly
     for row in D:
         assert_equal(row.min(), 0)
-
-
-if __name__ == '__main__':
-
-    run_module_suite()
