@@ -134,25 +134,25 @@ def add_noise(signal, snr, S0, noise_type='rician'):
     return noise_adder[noise_type](signal, noise1, noise2)
 
 
-def sticks_and_ball(gtab, d=0.0015, S0=1., angles=[(0, 0), (90, 0)],
-                    fractions=[35, 35], snr=20):
+def sticks_and_ball(gtab, d=0.0015, S0=1., angles=((0, 0), (90, 0)),
+                    fractions=(35, 35), snr=20):
     """ Simulate the signal for a Sticks & Ball model.
 
     Parameters
     ----------
     gtab : GradientTable
         Signal measurement directions.
-    d : float
+    d : float, optional
         Diffusivity value.
-    S0 : float
+    S0 : float, optional
         Unweighted signal value.
-    angles : array (K,2) or (K, 3)
+    angles : array (K, 2) or (K, 3), optional
         List of K polar angles (in degrees) for the sticks or array of K
         sticks as unit vectors.
-    fractions : float
+    fractions : array-like, optional
         Percentage of each stick.  Remainder to 100 specifies isotropic
         component.
-    snr : float
+    snr : float, optional
         Signal to noise ratio, assuming Rician noise.  If set to None, no
         noise is added.
 
@@ -230,7 +230,7 @@ def gaussian_parallel(q, tau, D=0.7e-3):
         q-space value in 1/mm
     tau : float
         diffusion time in s
-    D : float
+    D : float, optional
         diffusion constant
 
     Returns
@@ -242,9 +242,9 @@ def gaussian_parallel(q, tau, D=0.7e-3):
     return np.exp(-(2 * np.pi * q) ** 2 * tau * D)
 
 
-def cylinders_and_ball_soderman(gtab, tau, radii=[5e-3, 5e-3], D=0.7e-3,
-                                S0=1., angles=[(0, 0), (90, 0)],
-                                fractions=[35, 35], snr=20):
+def cylinders_and_ball_soderman(gtab, tau, radii=(5e-3, 5e-3), D=0.7e-3,
+                                S0=1., angles=((0, 0), (90, 0)),
+                                fractions=(35, 35), snr=20):
     r""" Calculates the three-dimensional signal attenuation E(q) originating
     from within a cylinder of radius R using the Soderman approximation [1]_.
     The diffusion signal is assumed to be separable perpendicular and parallel
@@ -258,19 +258,19 @@ def cylinders_and_ball_soderman(gtab, tau, radii=[5e-3, 5e-3], D=0.7e-3,
         Signal measurement directions.
     tau : float
         diffusion time in s
-    radii : float
+    radii : array-like, optional
         cylinder radius in mm
-    D : float
+    D : float, optional
         diffusion constant
-    S0 : float
+    S0 : float, optional
         Unweighted signal value.
-    angles : array (K,2) or (K, 3)
+    angles : array (K, 2) or (K, 3), optional
         List of K polar angles (in degrees) for the sticks or array of K
         sticks as unit vectors.
-    fractions : [float]
+    fractions : array-like, optional
         Percentage of each stick.  Remainder to 100 specifies isotropic
         component.
-    snr : float
+    snr : float, optional
         Signal to noise ratio, assuming Rician noise.  If set to None, no
         noise is added.
 
@@ -323,17 +323,17 @@ def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None):
         Table with information of b-values and gradient directions g.
         Note that if gtab has a btens attribute, simulations will be performed
         according to the given b-tensor B information.
-    S0 : double,
+    S0 : double, optional
         Strength of signal in the presence of no diffusion gradient (also
         called the ``b=0`` value).
-    evals : (3,) ndarray
+    evals : (3,) ndarray, optional
         Eigenvalues of the diffusion tensor.  By default, values typical for
         prolate white matter are used.
-    evecs : (3, 3) ndarray
+    evecs : (3, 3) ndarray, optional
         Eigenvectors of the tensor.  You can also think of this as a rotation
         matrix that transforms the direction of the tensor. The eigenvectors
         need to be column wise.
-    snr : float
+    snr : float, optional
         Signal to noise ratio, assuming Rician noise.  None implies no noise.
 
     Returns
@@ -378,8 +378,8 @@ def single_tensor(gtab, S0=1, evals=None, evecs=None, snr=None):
     return S.reshape(out_shape)
 
 
-def multi_tensor(gtab, mevals, S0=1., angles=[(0, 0), (90, 0)],
-                 fractions=[50, 50], snr=20):
+def multi_tensor(gtab, mevals, S0=1., angles=((0, 0), (90, 0)),
+                 fractions=(50, 50), snr=20):
     r""" Simulate a Multi-Tensor signal.
 
     Parameters
@@ -390,15 +390,15 @@ def multi_tensor(gtab, mevals, S0=1., angles=[(0, 0), (90, 0)],
         according to the given b-tensor information.
     mevals : array (K, 3)
         each tensor's eigenvalues in each row
-    S0 : float
+    S0 : float, optional
         Unweighted signal value (b0 signal).
-    angles : array (K,2) or (K,3)
+    angles : array (K, 2) or (K, 3), optional
         List of K tensor directions in polar angles (in degrees) or unit
         vectors
-    fractions : float
+    fractions : array-like, optional
         Percentage of the contribution of each tensor. The sum of fractions
         should be equal to 100%.
-    snr : float
+    snr : float, optional
         Signal to noise ratio, assuming Rician noise.  If set to None, no
         noise is added.
 
@@ -442,8 +442,8 @@ def multi_tensor(gtab, mevals, S0=1., angles=[(0, 0), (90, 0)],
     return add_noise(S, snr, S0), sticks
 
 
-def multi_tensor_dki(gtab, mevals, S0=1., angles=[(90., 0.), (90., 0.)],
-                     fractions=[50, 50], snr=20):
+def multi_tensor_dki(gtab, mevals, S0=1., angles=((90., 0.), (90., 0.)),
+                     fractions=(50, 50), snr=20):
     r""" Simulate the diffusion-weight signal, diffusion and kurtosis tensors
     based on the DKI model
 
@@ -529,7 +529,7 @@ def multi_tensor_dki(gtab, mevals, S0=1., angles=[(90., 0.), (90., 0.)],
     MD = (DT[0][0] + DT[1][1] + DT[2][2]) / 3
 
     # compute voxel's KT
-    kt = np.zeros((15))
+    kt = np.zeros(15)
     kt[0] = kurtosis_element(D_comps, fractions, 0, 0, 0, 0, DT, MD)
     kt[1] = kurtosis_element(D_comps, fractions, 1, 1, 1, 1, DT, MD)
     kt[2] = kurtosis_element(D_comps, fractions, 2, 2, 2, 2, DT, MD)
