@@ -1,15 +1,7 @@
-""" Testing decorators module
-"""
-
-import numpy as np
-
-from numpy.testing import (assert_almost_equal,
-                           assert_array_equal)
-
-from nose.tools import (assert_true, assert_false, assert_raises,
-                        assert_equal, assert_not_equal)
-
+"""Testing decorators module."""
 
+from numpy.testing import assert_raises, assert_equal
+from dipy.testing import assert_true
 from dipy.testing.decorators import doctest_skip_parser
 
 
