@@ -5,27 +5,21 @@ Run all benchmarks with::
     import dipy.tracking as dipytracking
     dipytracking.bench()
 
-If you have doctests enabled by default in nose (with a noserc file or
-environment variable), and you have a numpy version <= 1.6.1, this will also
-run the doctests, let's hope they pass.
+With Pytest, Run this benchmark with:
 
-Run this benchmark with:
+    pytest -svv -c bench.ini /path/to/bench_streamline.py
 
-    nosetests -s --match '(?:^|[\\b_\\.//-])[Bb]ench' bench_streamline.py
 """
 import numpy as np
 from numpy.testing import measure
 from numpy.testing import assert_array_equal, assert_array_almost_equal
 
-from dipy.data import get_data
-from nibabel import trackvis as tv
+from dipy.data import get_fnames
+from dipy.io.streamline import load_tractogram
 
-from dipy.tracking.streamline import (set_number_of_points,
-                                      length,
-                                      compress_streamlines)
+from dipy.tracking.streamline import set_number_of_points, length
 from dipy.tracking.tests.test_streamline import (set_number_of_points_python,
-                                                 length_python,
-                                                 compress_streamlines_python)
+                                                 length_python,)
 
 from dipy.tracking import Streamlines
 
@@ -109,9 +103,11 @@ def bench_length():
 
 def bench_compress_streamlines():
     repeat = 10
-    fname = get_data('fornix')
-    streams, hdr = tv.read(fname)
-    streamlines = [i[0] for i in streams]
+    fname = get_fnames('fornix')
+    fornix = load_tractogram(fname, 'same',
+                             bbox_valid_check=False).streamlines
+
+    streamlines = Streamlines(fornix)
 
     print("Timing compress_streamlines() in Cython"
           " ({0} streamlines)".format(len(streamlines)))
@@ -119,9 +115,7 @@ def bench_compress_streamlines():
     print("Cython time: {0:.3}sec".format(cython_time))
     del streamlines
 
-    fname = get_data('fornix')
-    streams, hdr = tv.read(fname)
-    streamlines = [i[0] for i in streams]
+    streamlines = Streamlines(fornix)
     python_time = measure("map(compress_streamlines_python, streamlines)",
                           repeat)
     print("Python time: {0:.2}sec".format(python_time))
