@@ -136,11 +136,11 @@ def grad_tensor(grad, evals):
     # This is the rotation matrix from [1, 0, 0] to this gradient of the sl:
     R = la.svd([grad], overwrite_a=True)[2]
     # This is the 3 by 3 tensor after rotation:
-    T = np.dot(np.dot(R, np.diag(evals)), R.T)
+    T = np.linalg.multi_dot([R, np.diag(evals), R.T])
     return T
 
 
-def streamline_tensors(streamline, evals=[0.001, 0, 0]):
+def streamline_tensors(streamline, evals=(0.001, 0, 0)):
     """
     The tensors generated by this fiber.
 
@@ -149,9 +149,8 @@ def streamline_tensors(streamline, evals=[0.001, 0, 0]):
     streamline : array-like of shape (n, 3)
         The 3d coordinates of a single streamline
 
-    evals : iterable with three entries
+    evals : iterable with three entries, optional
         The estimated eigenvalues of a single fiber tensor.
-        (default: [0.001, 0, 0]).
 
     Returns
     -------
@@ -174,7 +173,7 @@ def streamline_tensors(streamline, evals=[0.001, 0, 0]):
     return tensors
 
 
-def streamline_signal(streamline, gtab, evals=[0.001, 0, 0]):
+def streamline_signal(streamline, gtab, evals=(0.001, 0, 0)):
     """
     The signal from a single streamline estimate along each of its nodes.
 
@@ -184,7 +183,7 @@ def streamline_signal(streamline, gtab, evals=[0.001, 0, 0]):
 
     gtab : GradientTable class instance
 
-    evals : list of length 3 (optional. Default: [0.001, 0, 0])
+    evals : array-like of length 3, optional
         The eigenvalues of the canonical tensor used as an estimate of the
         signal generated by each node of the streamline.
     """
@@ -195,7 +194,7 @@ def streamline_signal(streamline, gtab, evals=[0.001, 0, 0]):
     bvecs = gtab.bvecs[~gtab.b0s_mask]
     bvals = gtab.bvals[~gtab.b0s_mask]
     for ii, tensor in enumerate(tensors):
-        ADC = np.diag(np.dot(np.dot(bvecs, tensor), bvecs.T))
+        ADC = np.diag(np.linalg.multi_dot([bvecs, tensor, bvecs.T]))
         # Use the Stejskal-Tanner equation with the ADC as input, and S0 = 1:
         sig[ii] = np.exp(-bvals * ADC)
     return sig - np.mean(sig)
@@ -207,7 +206,7 @@ class LifeSignalMaker(object):
     manner.
     """
 
-    def __init__(self, gtab, evals=[0.001, 0, 0], sphere=None):
+    def __init__(self, gtab, evals=(0.001, 0, 0), sphere=None):
         """
         Initialize a signal maker
 
@@ -215,10 +214,10 @@ class LifeSignalMaker(object):
         ----------
         gtab : GradientTable class instance
             The gradient table on which the signal is calculated.
-        evals : list of 3 items
+        evals : array-like of 3 items, optional
             The eigenvalues of the canonical tensor to use in calculating the
             signal.
-        sphere : `dipy.core.Sphere` class instance
+        sphere : `dipy.core.Sphere` class instance, optional
             The discrete sphere to use as an approximation for the continuous
             sphere on which the signal is represented. If integer - we will use
             an instance of one of the symmetric spheres cached in
@@ -243,7 +242,7 @@ class LifeSignalMaker(object):
             bvecs = self.gtab.bvecs[~self.gtab.b0s_mask]
             bvals = self.gtab.bvals[~self.gtab.b0s_mask]
             tensor = grad_tensor(self.sphere.vertices[idx], self.evals)
-            ADC = np.diag(np.dot(np.dot(bvecs, tensor), bvecs.T))
+            ADC = np.diag(np.linalg.multi_dot([bvecs, tensor, bvecs.T]))
             sig = np.exp(-bvals * ADC)
             sig = sig - np.mean(sig)
             self.signal[idx] = sig
@@ -323,7 +322,7 @@ class FiberModel(ReconstModel):
         # Initialize the super-class:
         ReconstModel.__init__(self, gtab)
 
-    def setup(self, streamline, affine, evals=[0.001, 0, 0], sphere=None):
+    def setup(self, streamline, affine, evals=(0.001, 0, 0), sphere=None):
         """
         Set up the necessary components for the LiFE model: the matrix of
         fiber-contributions to the DWI signal, and the coordinates of voxels
@@ -336,10 +335,10 @@ class FiberModel(ReconstModel):
         affine : array_like (4, 4)
             The mapping from voxel coordinates to streamline points.
             The voxel_to_rasmm matrix, typically from a NIFTI file.
-        evals : list (3 items, optional)
+        evals : array-like (3 items, optional)
             The eigenvalues of the canonical tensor used as a response
             function. Default:[0.001, 0, 0].
-        sphere: `dipy.core.Sphere` instance.
+        sphere: `dipy.core.Sphere` instance, optional
             Whether to approximate (and cache) the signal on a discrete
             sphere. This may confer a significant speed-up in setting up the
             problem, but is not as accurate. If `False`, we use the exact
@@ -437,7 +436,7 @@ class FiberModel(ReconstModel):
         return (to_fit, weighted_signal, b0_signal, relative_signal, mean_sig,
                 vox_data)
 
-    def fit(self, data, streamline, affine, evals=[0.001, 0, 0],
+    def fit(self, data, streamline, affine, evals=(0.001, 0, 0),
             sphere=None):
         """
         Fit the LiFE FiberModel for data and a set of streamlines associated
@@ -452,10 +451,10 @@ class FiberModel(ReconstModel):
         affine : array_like (4, 4)
             The mapping from voxel coordinates to streamline points.
             The voxel_to_rasmm matrix, typically from a NIFTI file.
-        evals : list (optional)
+        evals : array-like (optional)
             The eigenvalues of the tensor response function used in
             constructing the model signal. Default: [0.001, 0, 0]
-        sphere: `dipy.core.Sphere` instance, or False
+        sphere: `dipy.core.Sphere` instance or False, optional
             Whether to approximate (and cache) the signal on a discrete
             sphere. This may confer a significant speed-up in setting up the
             problem, but is not as accurate. If `False`, we use the exact
