@@ -1,7 +1,6 @@
 # Init file for visualization package
 import warnings
 
-from distutils.version import LooseVersion
 from dipy.utils.optpkg import optional_package
 # Allow import, but disable doctests if we don't have fury
 fury, has_fury, _ = optional_package(
@@ -12,26 +11,17 @@ fury, has_fury, _ = optional_package(
 
 
 if has_fury:
-    from fury import actor, window, colormap, interactor, ui, utils
-    from fury.window import vtk
+    from fury import actor, window, colormap, lib
+    from fury import interactor, ui, utils, shaders
     from fury.data import (fetch_viz_icons, read_viz_icons,
                            DATA_DIR as FURY_DATA_DIR)
 
-    HAVE_VTK_9_PLUS = vtk.vtkVersion.GetVTKMajorVersion() >= 9
-    HAVE_FURY_0_6_LESS = LooseVersion(fury.__version__) < LooseVersion('0.6.0')
-    if HAVE_VTK_9_PLUS and HAVE_FURY_0_6_LESS:
-        msg = "You are using VTK 9+ and FURY {}. ".format(fury.__version__)
-        msg += "Some functions might not work. To have a better experience, "
-        msg += "please upgrade to FURY version 0.6.0+. "
-        msg += "pip install -U fury"
-        warnings.warn(msg)
-
-
 else:
     warnings.warn(
         "You do not have FURY installed. "
-        "Some visualization functions might not work for you. "
-        "For installation instructions, please visit: https://fury.gl/")
+        "Therefore, 3D visualization functions will not work for you. "
+        "Please install or upgrade FURY using pip install -U fury"
+        "For detailed installation instructions visit: https://fury.gl/")
 
 # We make the visualization requirements optional imports:
 _, has_mpl, _ = optional_package(
