@@ -40,4 +40,6 @@ class GlobalHorizon(object):
         self.centroid_actors = []
         self.cluster_actors = []
 
-
+        # roi level sharing
+        self.roi_opacity = 1
+        self.slicer_roi_actor = []
