@@ -1,13 +1,15 @@
 import logging
 import os
+from tempfile import mkstemp, TemporaryDirectory
+
 import numpy.testing as npt
+
 from dipy.data import get_fnames
 from dipy.io.image import load_nifti
 from dipy.testing import assert_true
 from dipy.data.fetcher import dipy_home
 from dipy.workflows.io import IoInfoFlow, FetchFlow, SplitFlow
-from nibabel.tmpdirs import TemporaryDirectory
-from tempfile import mkstemp
+
 fname_log = mkstemp()[1]
 
 logging.basicConfig(level=logging.INFO,
@@ -62,7 +64,9 @@ def test_io_fetch_fetcher_datanames():
                      'scil_b0', 'sherbrooke_3shell', 'stanford_hardi',
                      'stanford_labels', 'stanford_pve_maps', 'stanford_t1',
                      'syn_data', 'taiwan_ntu_dsi', 'target_tractogram_hcp',
-                     'tissue_data', 'qte_lte_pte', 'resdnn_weights']
+                     'tissue_data', 'qte_lte_pte', 'resdnn_weights',
+                     'DiB_217_lte_pte_ste', 'DiB_70_lte_pte_ste', "hcp",
+                     "hbn"]
 
     num_expected_fetch_methods = len(dataset_names)
     npt.assert_equal(len(available_data), num_expected_fetch_methods)
