@@ -37,7 +37,7 @@ points of a streamline). To define a new way of extracting features, one has to
 subclass ``Feature`` (see below).
 
 The **distance computation** part includes any metric capable of evaluating a
-distance between two set of features previously extracted from the data. To
+distance between two sets of features previously extracted from the data. To
 define a new way of extracting features, one has to subclass ``Metric`` (see
 below).
 
@@ -59,17 +59,16 @@ arc length (i.e. the sum of the length of each segment for a given streamline).
 Let's start by importing the necessary modules.
 """
 
-from dipy.segment.metric import Feature
-from dipy.tracking.streamline import length
 import numpy as np
+
 from dipy.data import get_fnames
 from dipy.io.streamline import load_tractogram
 from dipy.tracking.streamline import Streamlines
 from dipy.viz import window, actor, colormap
 from dipy.segment.clustering import QuickBundles
-from dipy.segment.metric import SumPointwiseEuclideanMetric
-from dipy.segment.metric import Metric
-from dipy.segment.metric import VectorOfEndpointsFeature
+from dipy.segment.featurespeed import Feature, VectorOfEndpointsFeature
+from dipy.segment.metric import Metric, SumPointwiseEuclideanMetric
+from dipy.tracking.streamline import length
 
 """
 We now define the class ``ArcLengthFeature`` that will perform the desired
